% File src/library/base/man/Foreign.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2013 R Core Team
% Distributed under GPL 2 or later

\name{CallExternal}
\alias{.Call}
\alias{.External}
\title{Modern Interfaces to C/C++ code}
\description{
  \R に読み込まれているコンパイル済み C/C++ コードへ
  \R オブジェクトを引き渡す関数．
}
\usage{
    .Call(.NAME, \dots, PACKAGE)
.External(.NAME, \dots, PACKAGE)
}
\arguments{
  \item{.NAME}{C 関数の名前を表す文字列，もしくはそれらを参照する
  クラス \code{"\link{NativeSymbolInfo}"},
    \code{"\link{RegisteredNativeSymbol}"} または 
    \code{"\link{NativeSymbol}"} のオブジェクト．}

  \item{\dots}{コンパイルされたコードへ引き渡される引数．
  \code{.Call} に対しては最大65．}

  \item{PACKAGE}{もし与えられれば，文字列 \code{.NAME}
  の探索をこの引数で与えられる DLL に制限する
    (加えて通常の拡張子 \file{.so}, \file{.dll}, \dots).

    この引数は \code{...} の後に置かれているため，その名前は
    省略できない．

    これはパッケージに対する安全性を加えることを意図している．
    この引数使うことで他のどのパッケージもそれらの外部シンボルが
    上書きされ無いことが保証され，同時に探索を迅速にする
    (\sQuote{Note} を見よ)．}
}

\details{
  これらの関数は内部 \R オブジェクトを使用するコンパイル済みコードを
  呼び出すのに使われる．引数を \R オブジェクトの系列としてコードに
  引き渡す．慣例的な C の呼び出しを用いており，従って C++ コードに対しても
  使うことが出来る．

  これらの関数と共に使うコードをどのように書くかについては，
  マニュアル \sQuote{Writing \R Extensions} の章
  \sQuote{System and foreign language interfaces} を見よ．
  これらは引数を C コードに引き渡す仕方に関して異なる．
  \code{.External} は可変個数の引数を許す．

  これらの関数は \link{primitive} であり，\code{.NAME} は常に
  与えられる最初の引数(名前があってはならない)と照合される．
  明快さのために，\code{\dots} に引き渡される引数中の名前には
  \code{.NAME} に部分的に一致するものを使わない．
}

\value{
  コンパイル済みコード中で構成された \R オブジェクト．
}

\section{外部コードに対するヘッダーファイル}{
  これらの関数とともに使用するコードを書くためには
  \file{Rinternals.h} と \file{Rdefines.h} 中のマクロの
  双方もしくはどちらかで定義された \R の内部構造を使う必要がある．
}

\note{
  もしこれらの関数の一つを頻繁に使うのなら，
  \code{PACKAGE} を使う(単一の DLL へ検索を制限するため) か，もしくは
  \code{.NAME} をネイティブのシンボルオブジェクトの一つとして
  引き渡す．シンボルの検索は，特に多くの名前空間が
  読み込まれているとき，時間がかかる．

  \R にリンクされているシンボルは \code{PACKAGE = "base"}
  を見よ．これを自分自身のコード中で使ってはならない：
  そうしたシンボルは API の一部ではなく，警告なしに変更される
  可能性がある．

  \code{PACKAGE = ""} はかっては可能であった(がドキュメント化されていなかった):
  今はエラーになる．
}

\references{
  Chambers, J. M. (1998)
  \emph{Programming with Data.  A Guide to the S Language}.
  Springer. (\code{.Call}.)
}
\seealso{
  \code{\link{dyn.load}}, \code{\link{.C}}, \code{\link{.Fortran}}.

  The \sQuote{Writing R Extensions} manual.
}
\keyword{programming}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/Foreign.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2013 R Core Team
%% Distributed under GPL 2 or later
%
%\name{CallExternal}
%\alias{.Call}
%\alias{.External}
%\title{Modern Interfaces to C/C++ code}
%\description{
%  Functions to pass \R objects to compiled C/C++ code that has been
%  loaded into \R.
%}
%\usage{
%    .Call(.NAME, \dots, PACKAGE)
%.External(.NAME, \dots, PACKAGE)
%}
%\arguments{
%  \item{.NAME}{a character string giving the name of a C function,
%    or an object of class \code{"\link{NativeSymbolInfo}"},
%    \code{"\link{RegisteredNativeSymbol}"} or
%    \code{"\link{NativeSymbol}"} referring to such a name.}
%
%  \item{\dots}{arguments to be passed to the compiled code. Up to 65 for
%    \code{.Call}.}
%
%  \item{PACKAGE}{if supplied, confine the search for a character string
%    \code{.NAME} to the DLL given by this argument (plus the
%    conventional extension, \file{.so}, \file{.dll}, \dots).
%
%    This argument follows \code{...} and so its name cannot be abbreviated.
%
%    This is intended to add safety for packages, which can ensure by
%    using this argument that no other package can override their
%    external symbols, and also speeds up the search (see \sQuote{Note}).}
%}
%
%\details{
%  The functions are used to call compiled code which makes use of
%  internal \R objects, passing the arguments to the code as a sequence
%  of \R objects.  They assume C calling conventions, so can usually
%  also be used of C++ code.
%
%  For details about how to write code to use with these functions see
%  the chapter on \sQuote{System and foreign language interfaces} in
%  the \sQuote{Writing \R Extensions} manual.  They differ in the way the
%  arguments are passed to the C code:  \code{.External} allows for a
%  variable number of arguments.
%
%  These functions are \link{primitive}, and \code{.NAME} is always
%  matched to the first argument supplied (which should not be named).
%  For clarity, avoid using names in the arguments passed to \code{\dots}
%  that match or partially match \code{.NAME}.
%}
%
%\value{
%  An \R object constructed in the compiled code.
%}
%
%\section{Header files for external code}{
%  Writing code for use with these functions will need to use internal \R
%  structures defined in \file{Rinternals.h} and/or the macros in
%  \file{Rdefines.h}.
%}
%
%\note{
%  If one of these functions is to be used frequently, do specify
%  \code{PACKAGE} (to confine the search to a single DLL) or pass
%  \code{.NAME} as one of the native symbol objects.  Searching for
%  symbols can take a long time, especially when many namespaces are loaded.
%
%  You may see \code{PACKAGE = "base"} for symbols linked into \R.  Do
%  not use this in your own code: such symbols are not part of the API
%  and may be changed without warning.
%
%  \code{PACKAGE = ""} used to be accepted (but was undocumented): it is
%  now an error.
%}
%
%\references{
%  Chambers, J. M. (1998)
%  \emph{Programming with Data.  A Guide to the S Language}.
%  Springer. (\code{.Call}.)
%}
%\seealso{
%  \code{\link{dyn.load}}, \code{\link{.C}}, \code{\link{.Fortran}}.
%
%  The \sQuote{Writing R Extensions} manual.
%}
%\keyword{programming}
%
\encoding{UTF8}
