% File src/library/base/man/Recall.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{Recall}
\alias{Recall}
\title{Recursive Calling}
\usage{
Recall(\dots)
}
\arguments{
  \item{\dots}{引き渡されるすべての引数．}
}
\description{
  \code{Recall} はそれが中から呼び出される関数名の仮置き場として
使われる．これは後から名前が変わっても依然有効な再帰的
関数の定義に使える，以下の例を見よ．
}
\note{
  \code{Recall} は引数として関数を渡すと上手く動作しない．
  例えば\sspace{} \code{apply} 関数族．
}
\seealso{
  \code{\link{do.call}} と \code{\link{call}}．

匿名の再帰的関数を書く別の方法については \code{\link{local}}．
}
\examples{
## 自明(しかし非効率的な！)例:
fib <- function(n)
   if(n<=2) { if(n>=0) 1 else 0 } else Recall(n-1) + Recall(n-2)
fibonacci <- fib; rm(fib)
## 再命名は Recall 無しには上手く動作しないであろう
fibonacci(10) # 55
}
\keyword{programming}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/Recall.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{Recall}
%\alias{Recall}
%\title{Recursive Calling}
%\usage{
%Recall(\dots)
%}
%\arguments{
%  \item{\dots}{all the arguments to be passed.}
%}
%\description{
%  \code{Recall} is used as a placeholder for the name of the function
%  in which it is called.  It allows the definition of recursive
%  functions which still work after being renamed, see example below.
%}
%\note{
%  \code{Recall} will not work correctly when passed as a function
%  argument, e.g.\sspace{}to the \code{apply} family of functions.
%}
%\seealso{
%  \code{\link{do.call}} and \code{\link{call}}.
%
%  \code{\link{local}} for another way to write anonymous recursive functions.
%}
%\examples{
%## A trivial (but inefficient!) example:
%fib <- function(n)
%   if(n<=2) { if(n>=0) 1 else 0 } else Recall(n-1) + Recall(n-2)
%fibonacci <- fib; rm(fib)
%## renaming wouldn't work without Recall
%fibonacci(10) # 55
%}
%\keyword{programming}
%
%
\encoding{UTF8}
