% File src/library/base/man/basename.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2013 R Core Team
% Distributed under GPL 2 or later

\name{basename}
\alias{basename}
\alias{dirname}
\title{Manipulate File Paths}
\description{
  \code{basename} は最後のパス分離記号(もしあれば)とそれ以前のパスをすべて取り去る．

  \code{dirname} は最後のパス分離記号を除いてそれまでの \code{path} の部分を
  返す．もしくはパス分離器号がなければ \code{"."} を返す．
}
\usage{
basename(path)
dirname(path)
}
\arguments{
  \item{path}{文字列でパス名を含む．}
}
\details{
  \code{dirname} に対してはパスのチルダ展開が行われる．

  パスを分解する前に後に続くパス分離記号は取り除かれる．
  そして \code{dirname} に対してはすべてのファイル分離記号が
  結果から除かれる．
}
\section{Windows での挙動}{
  Windows ではこれは \code{\\} も \code{/} もパス分離記号として
  受け入れるが，\code{dirname} は \code{/} を使ったパスを返す
  (ネットワークシェアを除く，その時は先頭の \code{\\\\} が保存される)．
  これらは完全なパスを処理することだけを企図しており，例えば
  ネットワークシェアやドライブを考慮していない．

  現在のロケールで不正な UTF-8 でエンコードされたパス名を使うことが出来る．
}
\note{
  これらは同名の POSIX システム関数に対するラッパではない：
  特にこれらはパス \code{"/"} と空文字列に対する返り値 \code{"."} を
  特別に処理しない．
}
\value{
  \code{path} と同じ長さの文字列ベクトル．
  長さゼロの入力は長さゼロの出力を与えるがエラーにはならない．

  分離記号を全く含まないパスは現ディレクトリに所属するとされるので，
  \code{dirname} は \code{"."} を返す．

  \code{path} のある要素が \code{\link{NA}} ならば結果も同様になる．

  \code{""} は正しいパス名では無いが，そのままで返される．
}
\seealso{
  \code{\link{file.path}}, \code{\link{path.expand}}.
}
\examples{
basename(file.path("","p1","p2","p3", c("file1", "file2")))
dirname(file.path("","p1","p2","p3","filename"))
}
\keyword{file}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/basename.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2013 R Core Team
%% Distributed under GPL 2 or later
%
%\name{basename}
%\alias{basename}
%\alias{dirname}
%\title{Manipulate File Paths}
%\description{
%  \code{basename} removes all of the path up to and including the last
%  path separator (if any).
%
%  \code{dirname} returns the part of the \code{path} up to but
%  excluding the last path separator, or \code{"."} if there is no path
%  separator.
%}
%\usage{
%basename(path)
%dirname(path)
%}
%\arguments{
%  \item{path}{character vector, containing path names.}
%}
%\details{
%  For \code{dirname} \link{tilde expansion} of the path is done.
%
%  Trailing path separators are removed before dissecting the path,
%  and for \code{dirname} any trailing file separators are removed
%  from the result.
%}
%\section{Behaviour on Windows}{
%  On Windows this will accept either \code{\\} or \code{/} as the path
%  separator, but \code{dirname} will return a path using \code{/}
%  (except if on a network share, when the leading \code{\\\\} will be
%  preserved).  Expect these only to be able to handle complete
%  paths, and not for example just a network share or a drive.
%
%  UTF-8-encoded path names not valid in the current locale can be used.
%}
%\note{
%  These are not wrappers for the POSIX system functions of the same
%  names: in particular they do \strong{not} have the special handling of
%  the path \code{"/"} and of returning \code{"."} for empty strings.
%}
%\value{
%  A character vector of the same length as \code{path}.  A zero-length
%  input will give a zero-length output with no error.
%
%  Paths not containing any separators are taken to be in the current
%  directory, so \code{dirname} returns \code{"."}.
%
%  If an element of \code{path} is \code{\link{NA}}, so is the result.
%
%  \code{""} is not a valid pathname, but is returned unchanged.
%}
%\seealso{
%  \code{\link{file.path}}, \code{\link{path.expand}}.
%}
%\examples{
%basename(file.path("","p1","p2","p3", c("file1", "file2")))
%dirname(file.path("","p1","p2","p3","filename"))
%}
%\keyword{file}
%
\encoding{UTF8}
