% File src/library/base/man/curlGetHeaders.Rd
% Part of the R package, https://www.R-project.org
% Copyright 2015 R Core Team
% Distributed under GPL 2 or later

\name{curlGetHeaders}
\alias{curlGetHeaders}
\title{
  Retrieve Headers from URLs
}
\description{
  \code{http://}, \code{ftp://}, \code{https://} そして \code{ftps://}
  のようなサポートされるプロトコルに対する URL のヘッダーを取得する．
  すべてのプラットフォームではサポートされていないオプションの関数．
}
\usage{
curlGetHeaders(url, redirect = TRUE, verify = TRUE)
}

\arguments{
  \item{url}{URL を指定する文字列．}
  \item{redirect}{論理値：リダイレクションすべきか．}
  \item{verify}{論理値：認証は正しいとされそのホストに適用すべきか?}
}

\details{
  これは \command{curl -I -L} 又は \command{curl -I} が報告するものを
  報告する．\code{ftp://} URL に対しては\sQuote{ヘッダー}は
  データの転送前のクライアントとサーバー間の会話の記録である．

  500のヘッダー行だけが報告される：20のリダイレクションの制限があるので
  これは十分であろう(そして20ですら問題を指摘するかもしれない)．

  これは接続の時間切れに対して \code{\link{getOption}("timeout")} を使う：
  これは既定で60秒である．これは中断されないのでもっと短い値を
  使いたくなるかもしれない．

  サーバーとのやり取りのすべての詳細を見るには
  \code{\link{options}(internet.info = 1)} と設定せよ．
  
  HTTP[S] サーバーはヘッダーの読み取りへの要求等を拒否することが
  出来る：これは \code{405} という \code{status} になる．
  
  安全な URL (特に Windows 上で)に関する可能な事柄については
  \code{\link{download.file}} を見よ．

  認証を確認しないというセキュリティのリスクがあるかもしれないが，
  ヘッダーだけが取得されるので僅かである．
  普通ブラウザーで URL を眺めれば問題が何であるかが明らかになる
  (そしてこれは機械依存であるかもしれない)．
}
\value{
  整数値の属性 \code{"status"} (the
  last-received \sQuote{status} code) を持つ文字列．
  もしリダイレクトされれば，これは訪問されたすべての URL に
  対するヘッダーを含む．

  \sQuote{status} コードの解釈に対しては
  \url{https://en.wikipedia.org/wiki/List_of_HTTP_status_codes} そして
  \url{https://en.wikipedia.org/wiki/List_of_FTP_server_return_codes}
  を見よ．成功裏に行われた FTP コネクションは普通状態 250 か 350 を持つ．  
}

\seealso{
  これがサポートされているかどうかを見るには
  \code{\link{capabilities}("libcurl")}．

  \code{\link{options}} \code{HTTPUserAgent} そして \code{timeout}
  が使われる．
}

% http://forum.rebex.net/questions/1343/open-ftps-and-sftp-servers-for-testing-our-code-and-connectivity

\examples{\donttest{## インターネットアクセスが必要，結果は変わる
curlGetHeaders("http://bugs.r-project.org")   ## これは https:// にリダイレクトされる
curlGetHeaders("https://httpbin.org/status/404")  ## 状態を返す
curlGetHeaders("ftp://cran.r-project.org")
}
\dontrun{ ## 常に利用できるわけではないサイト：
curlGetHeaders("ftps://test.rebex.net/readme.txt")
}}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/curlGetHeaders.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{curlGetHeaders}
%\alias{curlGetHeaders}
%\title{
%  Retrieve Headers from URLs
%}
%\description{
%  Retrieve the headers for a URL for a supported protocol such as
%  \code{http://}, \code{ftp://}, \code{https://} and \code{ftps://}.
%  An optional function not supported on all platforms.
%}
%\usage{
%curlGetHeaders(url, redirect = TRUE, verify = TRUE)
%}
%
%\arguments{
%  \item{url}{character string specifying the URL.}
%  \item{redirect}{logical: should redirections be followed?}
%  \item{verify}{logical: should certificates be verified as valid
%    and applying to that host?}
%}
%
%\details{
%  This reports what \command{curl -I -L} or \command{curl -I} would
%  report.  For a \code{ftp://} URL the \sQuote{headers} are a record of
%  the conversation between client and server before data transfer.
%
%  Only 500 header lines will be reported: there is a limit of 20
%  redirections so this should suffice (and even 20 would indicate
%  problems).
%
%  It uses \code{\link{getOption}("timeout")} for the connection
%  timeout: that defaults to 60 seconds.  As this cannot be interrupted
%  you may want to consider a shorter value.
%
%  To see all the details of the interaction with the server(s) set
%  \code{\link{options}(internet.info = 1)}.
%  
%  HTTP[S] servers are allowed to refuse requests to read the headers and
%  some do: this will result in a \code{status} of \code{405}.
%  
%  For possible issues with secure URLs (especially on Windows) see
%  \code{\link{download.file}}.
%
%  There is a security risk in not verifying certificates, but as only
%  the headers are captured it is slight.  Usually looking at the URL in
%  a browser will reveal what the problem is (and it may well be
%  machine-specific).
%}
%\value{
%  A character vector with integer attribute \code{"status"} (the
%  last-received \sQuote{status} code).  If redirection occurs this will include
%  the headers for all the URLs visited.
%
%  For the interpretation of \sQuote{status} codes see
%  \url{https://en.wikipedia.org/wiki/List_of_HTTP_status_codes} and
%  \url{https://en.wikipedia.org/wiki/List_of_FTP_server_return_codes}.
%  A successful FTP connection will usually have status 250 or 350.  
%}
%
%\seealso{
%  \code{\link{capabilities}("libcurl")} to see if this is supported.
%
%  \code{\link{options}} \code{HTTPUserAgent} and \code{timeout} are used.
%}
%
%% http://forum.rebex.net/questions/1343/open-ftps-and-sftp-servers-for-testing-our-code-and-connectivity
%\examples{\donttest{## needs Internet access, results vary
%curlGetHeaders("http://bugs.r-project.org")   ## this redirects to https://
%curlGetHeaders("https://httpbin.org/status/404")  ## returns status
%curlGetHeaders("ftp://cran.r-project.org")
%}
%\dontrun{ ## a not-always-available site:
%curlGetHeaders("ftps://test.rebex.net/readme.txt")
%}}
%
\encoding{UTF8}
