% File src/library/base/man/debug.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{debug}
\title{Debug a Function}
\alias{debug}
\alias{debugonce}
\alias{undebug}
\alias{isdebugged}
\alias{debuggingState}
\usage{
debug(fun, text = "", condition = NULL)
debugonce(fun, text = "", condition = NULL)
undebug(fun)
isdebugged(fun)
debuggingState(on = NULL)
}
\arguments{
  \item{fun}{インタプリタ型の \R 関数．}
  \item{text}{ブラウザーが起動した時検索できる文字列．}
  \item{condition}{ブラウザーが起動した時検索できる条件．}
  \item{on}{論理値；サポート関数
    \code{debuggingState} の呼び出しは，もしデバッグ機能が大局的に
    開いた状態なら \code{TRUE} を返し, さもなければ \code{FALSE} を
    返す．これらの値の一つ又は他の引数は状態を設定する．
    もしデバッギング状態が 
    \code{FALSE} ならば，どのデバッグ行動も起きない(しかし関数中の明示的な
    \code{\link{browser}} 呼び出しは動作し続ける)．}
  %% can we describe what happens when it is turned off *inside* debugging ??
}
\description{
  関数に対するデバッギングフラグを設定，解除，確認する．
  \code{text} と \code{condition} 引数は \code{browser} への
  呼び出しを通じて提供できるものと同じである．
  一度ブラウザが導入されるとユーザはこれらを検索でき，
  ユーザがどのブレイクポイントが活性化したかを特定することが
  出来るようになる．
}
\details{
  デバッグ用のフラグを持つ関数が入力されると，
  通常の実行は中断され，関数本体は一度に一実行文ずつ実行される．
  新しいブラウザの文脈が各ステップごとに始められる(そして先の物は
  破棄される)．

  ユーザはデバッグのプロンプトに命令や \R 表現式(その後に新行)を入力できる．
  命令は \code{\link{browser}} のヘルプに詳細がある．

  他の関数の内部で定義されている関数をデバッグするには，
  一回のステップでその定義の最後まで進み，
  それからその名前に対して \code{debug} を呼び出す．

  もし先頭から始まっていない関数をデバッグしたければ
  \code{\link{trace}(..., at = *)} か \code{\link{setBreakpoint}}
  を使う．

  \code{debug} の使用は持続的で，デバッグを停止しない限り
  デバッガはすべての発動ごとに起動する
  (もし関数が取り除かれ置き換えられるとデバッグ状態は保存されないことを注意しよう)．
  次に関数が起動された時だけ \code{debugonce} を使ってデバッガを開始しよう．

  S4 メソッド(\code{\link{Methods}} を見よ)をデバッグするには，
  \code{\link{trace}} を使う必要がある．典型的には \code{\link{browser}} を
  呼び出す，つまり次のようにする\cr
  \code{trace("plot", browser, exit = browser, signature = c("track", "missing"))}

 関数がデバッグのために入力された時逆構文解析された呼び出し
 に対してプリントされる行数は \code{\link{options}(deparse.max.lines)} の設定で
 制限できる．

 バイトコンパイルされた関数に対してデバッギングを有効にすると，
 デバッギングが無効化されるまで関数のインタプリタ版が使われる．
}
\seealso{
  \code{\link{browser}}, \code{\link{trace}}；
  \code{Error: \dots} メッセージ後のスタックを見るためには
  \code{\link{traceback}}； 別のデバッグ法については \code{\link{recover}}．
}
\keyword{programming}
\keyword{environment}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/debug.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{debug}
%\title{Debug a Function}
%\alias{debug}
%\alias{debugonce}
%\alias{undebug}
%\alias{isdebugged}
%\alias{debuggingState}
%\usage{
%debug(fun, text = "", condition = NULL)
%debugonce(fun, text = "", condition = NULL)
%undebug(fun)
%isdebugged(fun)
%debuggingState(on = NULL)
%}
%\arguments{
%  \item{fun}{any interpreted \R function.}
%  \item{text}{a text string that can be retrieved when the browser is entered.}
%  \item{condition}{a condition that can be retrieved when the browser is entered.}
%  \item{on}{logical; a call to the support function
%    \code{debuggingState} returns \code{TRUE} if debugging is globally
%    turned on, \code{FALSE} otherwise.  An argument of one or the other
%    of those values sets the state.  If the debugging state is
%    \code{FALSE}, none of the debugging actions will occur (but explicit
%    \code{\link{browser}} calls in functions will continue to work).}
%  %% can we describe what happens when it is turned off *inside* debugging ??
%}
%\description{
%  Set, unset or query the debugging flag on a function.
%  The \code{text} and \code{condition} arguments are the same as those
%  that can be supplied via a call to \code{browser}. They can be retrieved
%  by the user once the browser has been entered, and provide a mechanism to
%  allow users to identify which breakpoint has been activated.
%}
%\details{
%  When a function flagged for debugging is entered, normal execution
%  is suspended and the body of function is executed one statement at a
%  time.  A new browser context is initiated for each step (and the
%  previous one destroyed).
%
%  At the debug prompt the user can enter commands or \R expressions,
%  followed by a newline.  The commands are described in the
%  \code{\link{browser}} help topic.
%
%  To debug a function which is defined inside another function,
%  single-step though to the end of its definition, and then call
%  \code{debug} on its name.
%
%  If you want to debug a function not starting at the very beginning,
%  use \code{\link{trace}(..., at = *)} or \code{\link{setBreakpoint}}.
%
%  Using \code{debug} is persistent, and unless debugging is turned off
%  the debugger will be entered on every invocation (note that if the
%  function is removed and replaced the debug state is not preserved).
%  Use \code{debugonce} to enter the debugger only the next time the
%  function is invoked.
%
%  In order to debug S4 methods (see \code{\link{Methods}}), you
%  need to use \code{\link{trace}}, typically calling \code{\link{browser}},
%  e.g., as \cr
%  \code{trace("plot", browser, exit = browser, signature = c("track", "missing"))}
%
%  The number of lines printed for the deparsed call when a function is
%  entered for debugging can be limited by setting
%  \code{\link{options}(deparse.max.lines)}.
%
%  When debugging is enabled on a byte compiled function then the
%  interpreted version of the function will be used until debugging is
%  disabled.
%}
%\seealso{
%  \code{\link{browser}}, \code{\link{trace}};
%  \code{\link{traceback}} to see the stack after an \code{Error: \dots}
%  message; \code{\link{recover}} for another debugging approach.
%}
%\keyword{programming}
%\keyword{environment}
%
\encoding{UTF8}
