% File src/library/base/man/dimnames.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{dimnames}
\title{Dimnames of an Object}
\alias{dimnames}
\alias{dimnames<-}
\alias{dimnames.data.frame}
\alias{dimnames<-.data.frame}
\alias{provideDimnames}
\description{
  オブジェクトの次元名を取り出したり設定したりする．
}
\usage{
dimnames(x)
dimnames(x) <- value

provideDimnames(x, sep = "", base = list(LETTERS))
}
\arguments{
  \item{x}{\R オブジェクト．例えば行列，配列もしくはデータフレーム．}
  \item{value}{\code{dimnames(x)} に対する可能な名前：
    \sQuote{値}節を見よ．}
  \item{sep}{文字列で構成された次元名中の \code{base} シンボルと数字を分離する．}
  \item{base}{文字列ベクトルの空でないリスト．リスト成分は順番に(必要ならリサイクル使用して)
    空の次元名成分に対する置き換えを構成するのに使われる．例も見よ．}
}
\details{
  関数 \code{dimnames} と \code{dimnames<-} は総称的である．

  配列(そして従って行列)に対しては，これらはオブジェクトの \code{dimnames} 
  属性(\link{attributes} を見よ)を取り出したり設定したりする. リスト
  \code{value} は名前を持つことができ，これらは適当であれば配列の次元の
  ラベルに使われる．

  配列/行列に対する置き換えメソッドは 
  \code{value} のベクトルと因子要素を文字列に強制変換するが，\code{as.character} に対する
  メソッドを選択適用しない．これは長さゼロの要素を \code{NULL} に，
  そして長さゼロのリストを \code{NULL} に強制変換する．もし \code{value} が
  次元の数よりも短いリストなら，それは必要な長さまで \code{NULL} を用いて拡大される．

  両方がデータフレームに対するメソッドを持つ．データフレームの次元名はその
  \code{\link{row.names}} と \code{\link{names}} である．置き換えメソッドに対しては
  \code{value} の各成分は \code{\link{as.character}} により強制変換される．

  1次元行列に対しては \code{\link{names}} は
  \code{dimnames} の(唯一の)成分と同じである．

  両方共プリミティブな関数である．

  \code{provideDimnames(x)} は欠損した箇所では \code{dimnames} を提供し，
  その結果は各成分に対して文字列の次元名を持つ．
}
\value{
  行列や配列の次元名は \code{NULL} (これは保管されない)になり得る．
  もしくは \code{dim(x)} と同じ長さのリストでも良い．もしリストなら
  その成分は \code{NULL} か \code{x} の適当な次元の正の長さを持つ文字列ベクトル
  である．このリストは名前を持つことが出来る．
  すべての成分が \code{NULL} になる可能性がある：そうした
  次元名は \code{NULL} に変換されるかもしれない．

  \code{"data.frame"} メソッドに対しては次元名は文字列ベクトルであり，
  行名は重複したり欠損した値を持ってはならない．

  \code{provideDimnames(x)} は \code{x} を返し，\dQuote{\code{NULL} を
  含まない} \code{dimnames} を持つ，つまり各成分は正しい長さを持つ文字列になる．
}
\note{
  \code{dimnames(A)[[1]] <- value} のような次元名成分の設定は
  普通に行われるが，もし付値される値が \code{NULL} ならば上手く動作しないことを注意しよう．
  代わりに \code{\link{rownames}} か，次元名リストすべてを操作しよう．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\seealso{
  \code{\link{rownames}}, \code{\link{colnames}};
  \code{\link{array}}, \code{\link{matrix}}, \code{\link{data.frame}}.
}
\examples{
## rownames と colnames の簡略版は次のように定義できる
rownames0 <- function(x) dimnames(x)[[1]]
colnames0 <- function(x) dimnames(x)[[2]]

(dn <- dimnames(A <- provideDimnames(N <- array(1:24, dim = 2:4))))
A0 <- A; dimnames(A)[2:3] <- list(NULL)
stopifnot(identical(A0, provideDimnames(A)))
strd <- function(x) utils::str(dimnames(x))
strd(provideDimnames(A, base= list(letters[-(1:9)], tail(LETTERS))))
strd(provideDimnames(N, base= list(letters[-(1:9)], tail(LETTERS)))) # リサイクル
strd(provideDimnames(A, base= list(c("AA","BB")))) # 双方のレベルについてリサイクル
}
\keyword{array}
\keyword{manip}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/dimnames.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{dimnames}
%\title{Dimnames of an Object}
%\alias{dimnames}
%\alias{dimnames<-}
%\alias{dimnames.data.frame}
%\alias{dimnames<-.data.frame}
%\alias{provideDimnames}
%\description{
%  Retrieve or set the dimnames of an object.
%}
%\usage{
%dimnames(x)
%dimnames(x) <- value
%
%provideDimnames(x, sep = "", base = list(LETTERS))
%}
%\arguments{
%  \item{x}{an \R object, for example a matrix, array or data frame.}
%  \item{value}{a possible value for \code{dimnames(x)}: see the
%    \sQuote{Value} section.}
%  \item{sep}{a character string, used to separate \code{base}
%    symbols and digits in the constructed dimnames.}
%  \item{base}{a non-empty \code{\link{list}} of character vectors.  The
%    list components are used in turn (and recycled when needed) to
%    construct replacements for empty dimnames components.  See also the
%    examples.}
%}
%\details{
%  The functions \code{dimnames} and \code{dimnames<-} are generic.
%
%  For an \code{\link{array}} (and hence in particular, for a
%  \code{\link{matrix}}), they retrieve or set the \code{dimnames}
%  attribute (see \link{attributes}) of the object.  A list
%  \code{value} can have names, and these will be used to label the
%  dimensions of the array where appropriate.
%
%  The replacement method for arrays/matrices coerces vector and factor
%  elements of \code{value} to character, but does not dispatch methods
%  for \code{as.character}.  It coerces zero-length elements to
%  \code{NULL}, and a zero-length list to \code{NULL}.  If \code{value}
%  is a list shorter than the number of dimensions, it is extended with
%  \code{NULL}s to the needed length.
%
%  Both have methods for data frames.  The dimnames of a data frame are
%  its \code{\link{row.names}} and its \code{\link{names}}.  For the
%  replacement method each component of \code{value} will be coerced by
%  \code{\link{as.character}}.
%
%  For a 1D matrix the \code{\link{names}} are the same thing as the
%  (only) component of the \code{dimnames}.
%
%  Both are \link{primitive} functions.
%
%  \code{provideDimnames(x)} provides \code{dimnames} where
%  \dQuote{missing}, such that its result has \code{\link{character}}
%  dimnames for each component.
%}
%\value{
%  The dimnames of a matrix or array can be \code{NULL} (which is not
%  stored) or a list of the same length as \code{dim(x)}.  If a list, its
%  components are either \code{NULL} or a character vector with positive
%  length of the appropriate dimension of \code{x}.  The list can have
%  names.  It is possible that all components are \code{NULL}: such
%  dimnames may get converted to \code{NULL}.
%
%  For the \code{"data.frame"} method both dimnames are character
%  vectors, and the rownames must contain no duplicates nor missing
%  values.
%
%  \code{provideDimnames(x)} returns \code{x}, with \dQuote{\code{NULL} -
%    free} \code{dimnames}, i.e.\sspace{}each component a character vector of
%  correct length.
%}
%\note{
%  Setting components of the dimnames, e.g.,
%  \code{dimnames(A)[[1]] <- value} is a common paradigm, but note that
%  it will not work if the value assigned is \code{NULL}.  Use
%  \code{\link{rownames}} instead, or (as it does) manipulate the whole
%  dimnames list.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\seealso{
%  \code{\link{rownames}}, \code{\link{colnames}};
%  \code{\link{array}}, \code{\link{matrix}}, \code{\link{data.frame}}.
%}
%\examples{
%## simple versions of rownames and colnames
%## could be defined as follows
%rownames0 <- function(x) dimnames(x)[[1]]
%colnames0 <- function(x) dimnames(x)[[2]]
%
%(dn <- dimnames(A <- provideDimnames(N <- array(1:24, dim = 2:4))))
%A0 <- A; dimnames(A)[2:3] <- list(NULL)
%stopifnot(identical(A0, provideDimnames(A)))
%strd <- function(x) utils::str(dimnames(x))
%strd(provideDimnames(A, base= list(letters[-(1:9)], tail(LETTERS))))
%strd(provideDimnames(N, base= list(letters[-(1:9)], tail(LETTERS)))) # recycling
%strd(provideDimnames(A, base= list(c("AA","BB")))) # recycling on both levels
%}
%\keyword{array}
%\keyword{manip}
%
\encoding{UTF8}
