% File src/library/base/man/file.access.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{file.access}
\alias{file.access}
\title{Ascertain File Accessibility}
\description{
  ユーザのファイルシステムにあるファイルに関する情報にアクセスするユーティリティ関数．
}
\usage{
file.access(names, mode = 0)
}
\arguments{
  \item{names}{ファイル名を含む文字列ベクトル．
    チルドの拡張が行われる：\code{\link{path.expand}} を見よ．}
  \item{mode}{要求されるアクセスモードを指定する整数：\sQuote{詳細}を見よ．}
}
\details{
  \code{mode} 値はvalue can be the exclusive or of the following values
  \describe{
    \item{0}{存在のテスト．}
    \item{1}{実行許可のテスト．}
    \item{2}{書き込み許可のテスト．}
    \item{4}{読み込み許可のテスト．}
  }
#ifdef unix
  パーミッションは実ユーザ ID と実グループID (実効的な ID ではなく)から計算される．
#endif
#ifdef windows
  この関数は \file{msvcrt.dll} 中の C 関数 \code{_access} を利用しているが，
  Win32 API 関数を使って書かれていた．

  Windows は \sQuote{実行可能ファイル} の概念を持っていないので，
  この関数は拡張子
  \file{.exe}, \file{.bat}, \file{.cmd} そして \file{.com} を
  持つディレクトリとファイルを実行可能と見做す．
  (\code{\link{system}} と \code{\link{Sys.which}} は同じ仮定を置く．)

  現在のロケールでは不正な UTF-8 でエンコードされたファイル名が使える．
#endif

  ファイルをオープンする前にこの関数を検査のために使うのは良い考えではないことを
  注意してほしい．マルチタスクのシステムではファイルのアクセス状態が
  \code{file.access()} を呼び出している時とファイルのオープンを試みる時の
  間に変わることがあり得る．
  ファイルのオープンの試みを \code{\link{try}} の中にラップする方が良い．
}
\value{
  整数ベクトルで成功なら値 \code{0} で失敗なら \code{-1}．
}

\note{
  これは S-PLUS の関数 \code{access}，同じ名前の C 関数に対するラッパ，の代替物
  を意図しているおり，それから返り値のエンコーディングが由来する．
  返り値が \bold{success} に対して \bold{false} であることを注意する．
}

\seealso{
  パーミッションに関するより詳細は \code{\link{file.info}}，
  パーミッションの変更には \code{\link{Sys.chmod}}，そして
  \sQuote{テストしてそして眺める}アプローチには \code{\link{try}}．

  シェル風のファイル検査 \code{\link{file_test}}．
}

\examples{
fa <- file.access(dir("."))
table(fa) # 成功と失敗を数える
#ifdef windows
d <- dir(file.path(R.home(), "bin"))
df <- dir(file.path(R.home(), "bin"), full.names = TRUE)
d[file.access(df, 0) == 0] # すべて存在
d[file.access(df, 1) == 0] # 幾つかは実行可能ファイルで，幾つかはそうではない
d[file.access(df, 4) == 0] # 全部が可読であってほしい
d[file.access(df, 2) == 0] # これらは書き込み可能であったりなかったりする
#endif
}
\keyword{file}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/file.access.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{file.access}
%\alias{file.access}
%\title{Ascertain File Accessibility}
%\description{
%  Utility function to access information about files on the user's
%  file systems.
%}
%\usage{
%file.access(names, mode = 0)
%}
%\arguments{
%  \item{names}{character vector containing file names.
%    Tilde-expansion will be done: see \code{\link{path.expand}}.}
%  \item{mode}{integer specifying access mode required: see \sQuote{Details}.}
%}
%\details{
%  The \code{mode} value can be the exclusive or of the following values
%  \describe{
%    \item{0}{test for existence.}
%    \item{1}{test for execute permission.}
%    \item{2}{test for write permission.}
%    \item{4}{test for read permission.}
%  }
%#ifdef unix
%  Permission will be computed for real user ID and real group ID (rather
%  than the effective IDs).
%#endif
%#ifdef windows
%  This function does uses the C function \code{_access} in
%  \file{msvcrt.dll}, but was written using Win32 API functions.
%
%  Windows does not have the concept of an \sQuote{executable file}, so
%  this function regards directories and files with extension
%  \file{.exe}, \file{.bat}, \file{.cmd} and \file{.com} as executable.
%  (\code{\link{system}} and \code{\link{Sys.which}} make the same assumption.)
%
%  UTF-8-encoded file names not valid in the current locale can be used.
%#endif
%
%  Please note that it is not a good idea to use this function to test
%  before trying to open a file.  On a multi-tasking system, it is
%  possible that the accessibility of a file will change between the time
%  you call \code{file.access()} and the time you try to open the file.
%  It is better to wrap file open attempts in \code{\link{try}}.
%}
%\value{
%  An integer vector with values \code{0} for success and \code{-1} for failure.
%}
%
%\note{
%  This is intended as a replacement for the S-PLUS function
%  \code{access}, a wrapper for the C function of the same name, which
%  explains the return value encoding.  Note that
%  the return value is \bold{false} for \bold{success}.
%}
%
%\seealso{
%  \code{\link{file.info}} for more details on permissions,
%  \code{\link{Sys.chmod}} to change permissions, and
%  \code{\link{try}} for a \sQuote{test it and see} approach.
%
%  \code{\link{file_test}} for shell-style file tests.
%}
%
%\examples{
%fa <- file.access(dir("."))
%table(fa) # count successes & failures
%#ifdef windows
%d <- dir(file.path(R.home(), "bin"))
%df <- dir(file.path(R.home(), "bin"), full.names = TRUE)
%d[file.access(df, 0) == 0] # all exist
%d[file.access(df, 1) == 0] # some are executable, some are not
%d[file.access(df, 4) == 0] # hopefully all are readable
%d[file.access(df, 2) == 0] # they may or may not be writable
%#endif
%}
%\keyword{file}
%






\encoding{UTF8}
