% File src/library/base/man/files.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{files2}
\alias{dir.create}
\alias{dir.exists}
\alias{Sys.chmod}
\alias{Sys.umask}
\concept{directory}
\concept{mkdir}
\alias{umask} % for links
\title{Manipulaton of Directories and File Permissions}
\description{
  これらの関数は計算機のファイルシステムへの低水準のインタフェイスを提供する．
}
\usage{
dir.exists(paths)
dir.create(path, showWarnings = TRUE, recursive = FALSE, mode = "0777")
Sys.chmod(paths, mode = "0777", use_umask = TRUE)
Sys.umask(mode = NA)
}
\arguments{
  \item{path}{単一のパス名を含む文字列ベクトル．
  チルド展開がされる(\code{\link{path.expand}} を見よ)．．}
  \item{paths}{フィアル又はディレクトリパスを含む文字列ベクトル．
  チルド展開がされる(\code{\link{path.expand}} を見よ)．．}
    \item{showWarnings}{論理値；失敗辞に警告を出すか?}
  \item{recursive}{論理値．最後を除くパス要素を作り出すか?
    もし真なら Unix 命令 \command{mkdir -p} のようになる．}
  \item{mode}{Unix 風システムで使われるモード：
    \code{\link{as.octmode}} で強制変換される．\code{Sys.chmod} に対してはこれは
    \code{paths} に沿ってリサイクルされる．}
  \item{use_umask}{論理値：モードは \code{umask} の設定により制限されるべきか?}
}
\details{
  \code{dir.create} は \code{recursive = TRUE} で無い限りパスの最後の要素を作成する．
  末尾のパス分離記号は捨てられる．
#ifdef windows
  Windows ではドライブはパス指定中に許され，パスがルートから始まっていない限り
  そのドライブの現在のディレクトリに相対的と解釈される．
  \code{mode} は Windows では無視される．
#endif
#ifdef unix
  モードはシステム関数 \code{mkdir} に於けるのと同様に \code{umask} の設定で
  修正される．どのようなモードが設定できるかは OS 依存で三つの8進数の桁以上のことを
  仮定するのは安全ではない．
  より詳細は OS のシステムコール \code{mkdir} に関するドキュメントを見よ，例えば
  \command{man 2 mkdir} (その名前のコマンドラインユーティリティーについてではない)．
#endif

  Windows の特異な点の一つがディレクトリ作成が成功したと報告されるにもかかわらず
  異なった名前のディレクトリが作られることである．例えば
  \code{dir.create("G.S.")} は \file{"G.S"} を作る．これはドキュメント化されて
  おらず，何が正しい状況なのかは不明である(Windows のバージョンによるかもしれない)．
  また末尾に空白の付くディレクトリ名も避けよう．
  %% http://msdn.microsoft.com/en-us/library/aa365247%28VS.85%29.aspx
  %% is vague about this!

  \code{Sys.chmod} は一つもしくはそれ以上のファイルのファイルパーミッションを設定する．
#ifdef unix
  システムがそれをサポートしていないかもしれない(警告が出された時)．
  モードがどのように解釈されるかについては \code{dir.create} に対する説明を見よ．
  シンボリックリンクへのモードの変更は動作しそうもない(そして不要である)．
  より詳細に潰えは OS のシステムコール \code{chmod} に関するドキュメントを見よ，
  例えば \command{man 2 chmod} (そしてその名前のコマンドラインユーティリティーに
  ついてではない).  これがシンボリックリンクやそのターゲットのパーミッションを変える
  どうかは OS 依存である(ターゲットを変えることがより普通ではあるが，そして
  POSIX はシンボリックリンクに対するモードをサポートしていない：しかし
  BSD ベースの Unix はする)．
#endif
#ifdef windows
  Windows のシステム関数での \code{mode} の解釈は非POSIXでファイルの読み取りオンリー属性
  の設定だけをサポートする．従って \R は \code{mode} を \code{(mode & 0200) == 0}
  (8進数で解釈)の時，そしてその時だけ読み取りオンリー設定を意味すると
  解釈する．Windows はある種のファイルシステム(例えば NTFS のバージョン)に
  ついてはより徹底したファイルシステムパーミッションのシステムを持ち，
  これらはこのシステムコールとは無関係である．
#endif

  \code{Sys.umask} か \code{umask} を設定し前の値を返す：
  特別な場合として \code{mode = NA} は単に現在の値を返す．
#ifdef unix
  これはサポートされていないかもしれない(警告が出て \code{"0"} が
  返される時)． より詳細は OS のシステムコール \code{umask} に関する
  ドキュメントを見よ，例えば \command{man 2 umask}．
#endif
#ifdef windows
  Windows のすべてのファイルは読み取り可能と見做される．
  そしてファイルが実行可能は Windows の概念ではない．従って
  \code{umask} はファイルが書き込み可能かどうかだけを制御する：
  設定 \code{"200"} はその後に作成されたファイル(しかしディレクトリではない)
  を読み込みオンリーにする．
#endif
%% http://msdn.microsoft.com/en-us/library/5axxx3be%28v=vs.80%29.aspx

  モードがどのように処理されるかはファイルシステムに依存する．
  これは Unix 風システムでも同様である
  (それらのドキュメントはしばしば POSIX ファイルシステムを仮定して書かれて
  いるにもかかわらず)．従ってもし，例えば
  FAT/FAT32 や network-mounted ファイルシステムを使っているならば
  ドキュメントを用心深く扱おう．
}
\value{
  \code{dir.exists} は値 \code{TRUE} か \code{FALSE} の論理値ベクトルを返す(名前はない)．
  
  \code{dir.create} と \code{Sys.chmod} は試みられた各ファイルに対し操作が成功したかを
  示す論理値ベクトルを不可視で返す．
  パス名として欠損値を使うと常に失敗と見做される．
  \code{dir.create} はディレクトリが既に存在すると失敗と指示する．
  もし \code{showWarnings = TRUE} なら \code{dir.create} は予期しない失敗に対して
  警告を与える(例えば欠損値でもなく \code{recursive = TRUE}) に対して既に存在する
  成分に対してでもなく)．

  \code{Sys.umask} は \code{umask} の前の値を返す，これは
  長さ1のオブジェクでクラスは \code{"\link{octmode}"} である：可視フラグは
  \code{mode} が \code{NA} で無い限りオフである．

  \code{path} と \code{paths} の解釈に対する大・小文字を区別しない
  ファイルシステムに関する \code{\link{file.exists}} のヘルプの節を見よ．
}
#ifdef windows
\note{
  これらの関数が Windows の \file{d:path} の形の相対パスを処理する保証はない:
  代わりに \file{d:./path} を使おう．
  特に \file{d:} はディレクトリとして認識されない．
  同じく \samp{\\\\?\\} 接頭語(そして類似物)はサポートされない．

  これらの関数の多くは現在のロケールで不正な UTF-8 ファイルパスを受け入れる．

}
#endif

\author{
  Ross Ihaka, Brian Ripley
}
\seealso{
  \code{\link{file.info}}, \code{\link{file.exists}}, \code{\link{file.path}},
  \code{\link{list.files}}, \code{\link{unlink}},
  \code{\link{basename}}, \code{\link{path.expand}}.
}

\examples{\dontrun{
## 許される最大のパーミッションをファイルツリー中にあてがう
Sys.chmod(list.dirs("."), "777")
f <- list.files(".", all.files = TRUE, full.names = TRUE, recursive  TRUE)
Sys.chmod(f, (file.info(f)$mode | "664"))
}}
\keyword{file}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/files.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{files2}
%\alias{dir.create}
%\alias{dir.exists}
%\alias{Sys.chmod}
%\alias{Sys.umask}
%\concept{directory}
%\concept{mkdir}
%\alias{umask} % for links
%\title{Manipulaton of Directories and File Permissions}
%\description{
%  These functions provide a low-level interface to the computer's
%  file system.
%}
%\usage{
%dir.exists(paths)
%dir.create(path, showWarnings = TRUE, recursive = FALSE, mode = "0777")
%Sys.chmod(paths, mode = "0777", use_umask = TRUE)
%Sys.umask(mode = NA)
%}
%\arguments{
%  \item{path}{a character vector containing a single path name.  Tilde
%    expansion (see \code{\link{path.expand}}) is done.}
%  \item{paths}{character vectors containing file or directory paths.  Tilde
%    expansion (see \code{\link{path.expand}}) is done.}
%  \item{showWarnings}{logical; should the warnings on failure be shown?}
%  \item{recursive}{logical. Should elements of the path other than the
%    last be created?  If true, like the Unix command \command{mkdir -p}.}
%  \item{mode}{the mode to be used on Unix-alikes: it will be
%    coerced by \code{\link{as.octmode}}.  For \code{Sys.chmod} it is
%    recycled along \code{paths}.}
%  \item{use_umask}{logical: should the mode be restricted by the
%    \code{umask} setting?}
%}
%\details{
%  \code{dir.create} creates the last element of the path, unless
%  \code{recursive = TRUE}.  Trailing path separators are discarded.
%#ifdef windows
%  On Windows drives are allowed in the path specification and unless
%  the path is rooted, it will be interpreted relative to the current
%  directory on that drive.  \code{mode} is ignored on Windows.
%#endif
%#ifdef unix
%  The mode will be modified by the \code{umask} setting in the same way
%  as for the system function \code{mkdir}.  What modes can be set is
%  OS-dependent, and it is unsafe to assume that more than three octal
%  digits will be used.  For more details see your OS's documentation on the
%  system call \code{mkdir}, e.g.\sspace{}\command{man 2 mkdir} (and not that on
%  the command-line utility of that name).
%#endif
%
%  One of the idiosyncrasies of Windows is that directory creation may
%  report success but create a directory with a different name, for
%  example \code{dir.create("G.S.")} creates \file{"G.S"}.  This is
%  undocumented, and what are the precise circumstances is unknown (and
%  might depend on the version of Windows).  Also avoid directory names
%  with a trailing space.
%  %% http://msdn.microsoft.com/en-us/library/aa365247%28VS.85%29.aspx
%  %% is vague about this!
%
%  \code{Sys.chmod} sets the file permissions of one or more files.
%#ifdef unix
%  It may not be supported on a system (when a warning is issued).
%  See the comments for \code{dir.create} for how modes are interpreted.
%  Changing mode on a symbolic link is unlikely to work (nor be
%  necessary).  For more details see your OS's documentation on the
%  system call \code{chmod}, e.g.\sspace{}\command{man 2 chmod} (and not that on
%  the command-line utility of that name).  Whether this changes the
%  permission of a symbolic link or its target is OS-dependent (although
%  to change the target is more common, and POSIX does not support modes
%  for symbolic links: BSD-based Unixes do, though).
%#endif
%#ifdef windows
%  The interpretation of \code{mode} in the Windows system functions is
%  non-POSIX and only supports setting the read-only attribute of the
%  file.  So \R interprets \code{mode} to mean set read-only if and only
%  if \code{(mode & 0200) == 0} (interpreted in octal).  Windows has a much
%  more extensive system of file permissions on some file systems
%  (e.g., versions of NTFS) which are unrelated to this system call.
%#endif
%
%  \code{Sys.umask} sets the \code{umask} and returns the previous value:
%  as a special case \code{mode = NA} just returns the current value.
%#ifdef unix
%  It may not be supported (when a warning is issued and \code{"0"}
%  is returned).  For more details see your OS's documentation on the
%  system call \code{umask}, e.g.\sspace{}\command{man 2 umask}.
%#endif
%#ifdef windows
%  All files on Windows are regarded as readable, and files being
%  executable is not a Windows concept.  So \code{umask} only controls
%  whether a file is writable: a setting of \code{"200"} makes files (but
%  not directories) created subsequently read-only.
%#endif
%%% http://msdn.microsoft.com/en-us/library/5axxx3be%28v=vs.80%29.aspx
%
%  How modes are handled depends on the file system, even on Unix-alikes
%  (although their documentation is often written assuming a POSIX file
%  system).  So treat documentation cautiously if you are using, say, a
%  FAT/FAT32 or network-mounted file system.
%}
%\value{
%  \code{dir.exists} returns a logical vector of \code{TRUE} or
%  \code{FALSE} values (without names).
%  
%  \code{dir.create} and \code{Sys.chmod} return invisibly a logical vector
%  indicating if the operation succeeded for each of the files attempted.
%  Using a missing value for a path name will always be regarded as a
%  failure.  \code{dir.create} indicates failure if the directory already
%  exists.  If \code{showWarnings = TRUE}, \code{dir.create} will give a
%  warning for an unexpected failure (e.g., not for a missing value nor
%  for an already existing component for \code{recursive = TRUE}).
%
%  \code{Sys.umask} returns the previous value of the \code{umask},
%  as a length-one object of class \code{"\link{octmode}"}: the
%  visibility flag is off unless \code{mode} is \code{NA}.
%
%  See also the section in the help for \code{\link{file.exists}} on
%  case-insensitive file systems for the interpretation of \code{path}
%  and \code{paths}.
%}
%#ifdef windows
%\note{
%  There is no guarantee that these functions will handle Windows
%  relative paths of the form \file{d:path}: try \file{d:./path}
%  instead.  In particular, \file{d:} is not recognized as a directory.
%  Nor are \samp{\\\\?\\} prefixes (and similar) supported.
%
%  UTF-8-encoded dirnames not valid in the current locale can be used.
%}
%#endif
%
%\author{
%  Ross Ihaka, Brian Ripley
%}
%\seealso{
%  \code{\link{file.info}}, \code{\link{file.exists}}, \code{\link{file.path}},
%  \code{\link{list.files}}, \code{\link{unlink}},
%  \code{\link{basename}}, \code{\link{path.expand}}.
%}
%
%\examples{\dontrun{
%## Fix up maximal allowed permissions in a file tree
%Sys.chmod(list.dirs("."), "777")
%f <- list.files(".", all.files = TRUE, full.names = TRUE, recursive  TRUE)
%Sys.chmod(f, (file.info(f)$mode | "664"))
%}}
%\keyword{file}
%
\encoding{UTF8}
