% File src/library/base/man/format.info.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2011 R Core Team
% Distributed under GPL 2 or later

\name{format.info}
\alias{format.info}
\title{format(.) Information}
\description{
  \code{\link{format}(x, digits, nsmall)} がどのように整形されるかに関する
  情報が返される．
}
\usage{
format.info(x, digits = NULL, nsmall = 0)
}
\arguments{
 \item{x}{原子的ベクトル；\code{\link{format}(x, \dots)} の可能性のある引数．}
  \item{digits}{数値と複素数値の \code{x} に対してどれだけの有効桁数を使うか
    既定値 \code{NULL} は \code{\link{getOption}("digits")} を使う．}
  \item{nsmall}{ (\code{\link{format}(\dots, nsmall)} を見よ)．}
}

\value{
  長さ 1,3 又は 6 の整数ベクトル，例えば \code{r} とする．

  論理値，整数そして文字列ベクトルに対しては単一の要素で，
  \code{width = NULL} ならば \code{format} で使われる幅． 

  数値ベクトルに対しては：
  \item{r[1]}{\code{format(x)} が使う幅(文字単位)．}
  \item{r[2]}{小数点以下の桁数．}
  \item{r[3]}{\code{0:2} 中；もし \eqn{\ge}\code{1} なら
    指数表記が使われ，指数部は長さ \code{r[3]+1}．}

  複素数値ベクトルに対しては最初の三つの要素は実部を参照し，
  虚部に対応する追加の三つの要素がある．
}
\seealso{
  \code{\link{format}} (特に \code{digits >= 16} について),
  \code{\link{formatC}}.
}
\examples{
dd <- options("digits") ; options(digits = 7) #-- 以下のために
format.info(123)   # 3 0 0
format.info(pi)    # 8 6 0
format.info(1e8)   # 5 0 1 - 指数表記 "1e+08"
format.info(1e222) # 6 0 2 - 指数表記 "1e+222"

x <- pi*10^c(-10,-2,0:2,8,20)
names(x) <- formatC(x, width = 1, digits = 3, format = "g")
cbind(sapply(x, format))
t(sapply(x, format.info))

## "." の右に少なくとも8桁
t(sapply(x, format.info, nsmall = 8))

# 古いオプションをリセット：
options(dd)
}
\keyword{character}
\keyword{print}
\keyword{programming}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/format.info.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2011 R Core Team
%% Distributed under GPL 2 or later
%
%\name{format.info}
%\alias{format.info}
%\title{format(.) Information}
%\description{
%  Information is returned on how \code{\link{format}(x, digits, nsmall)}
%  would be formatted.
%}
%\usage{
%format.info(x, digits = NULL, nsmall = 0)
%}
%\arguments{
% \item{x}{an atomic vector; a potential argument of
%   \code{\link{format}(x, \dots)}.}
%  \item{digits}{how many significant digits are to be used for
%    numeric and complex \code{x}.  The default, \code{NULL}, uses
%    \code{\link{getOption}("digits")}.}
%  \item{nsmall}{ (see \code{\link{format}(\dots, nsmall)}).}
%}
%
%\value{
%  An \code{\link{integer}} \code{\link{vector}} of length 1, 3 or 6, say
%  \code{r}.
%
%  For logical, integer and character vectors a single element,
%  the width which would be used by \code{format} if \code{width = NULL}.
%
%  For numeric vectors:
%  \item{r[1]}{width (in characters) used by \code{format(x)}}
%  \item{r[2]}{number of digits after decimal point.}
%  \item{r[3]}{in \code{0:2}; if \eqn{\ge}\code{1}, \emph{exponential}
%    representation would be used, with exponent length of \code{r[3]+1}.}
%
%  For a complex vector the first three elements refer to the real parts,
%  and there are three further elements corresponding to the imaginary
%  parts.
%}
%\seealso{
%  \code{\link{format}} (notably about \code{digits >= 16}),
%  \code{\link{formatC}}.
%}
%\examples{
%dd <- options("digits") ; options(digits = 7) #-- for the following
%format.info(123)   # 3 0 0
%format.info(pi)    # 8 6 0
%format.info(1e8)   # 5 0 1 - exponential "1e+08"
%format.info(1e222) # 6 0 2 - exponential "1e+222"
%
%x <- pi*10^c(-10,-2,0:2,8,20)
%names(x) <- formatC(x, width = 1, digits = 3, format = "g")
%cbind(sapply(x, format))
%t(sapply(x, format.info))
%
%## using at least 8 digits right of "."
%t(sapply(x, format.info, nsmall = 8))
%
%# Reset old options:
%options(dd)
%}
%\keyword{character}
%\keyword{print}
%\keyword{programming}
%
\encoding{UTF8}
