% File src/library/base/man/iconv.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{iconv}
\alias{iconv}
\alias{iconvlist}
\concept{encoding}
\title{Convert Character Vector between Encodings}
\description{
  これは文字列ベクトルをエンコーディング間で変換するために
  システムの機能を使う：
  \sQuote{i} は \sQuote{internationalization} を意味する．
}
\usage{
iconv(x, from = "", to = "", sub = NA, mark = TRUE, toRaw = FALSE)

iconvlist()
}

\arguments{
  \item{x}{文字列ベクトル，又は \code{\link{as.character}} で文字列ベクトルに変換される
    オブジェクト，又は \code{iconv(toRaw = TRUE)} で返されるような
    \code{NULL} と \code{raw} 要素を持つリスト．}
  \item{from}{現在のエンコーディングを記述する文字列．}
  \item{to}{目標のエンコーディングを記述する文字列．}
  \item{sub}{文字列．もし \code{NA} でなければ入力中の変換不能なバイトを置き換える
    のに使われる．(これは普通単一の文字であるが，それ以上でも良い．)
    もし \code{"byte"} はバイトの16進数コードである \code{"<xx>"} を意味する．}
  \item{mark}{論理値．熟練者用．エンコーディングはマークすべきか?}
  \item{toRaw}{論理値．文字列ベクトルではなくバイトベクトルのリストを返すべきか?}
}

\details{
  エンコーディングの名前と何が利用できるかはプラットフォーム依存である．
  すべての \R のプラットフォームは \code{""} (現在のロケールのエンコーディング
  に対して), \code{"latin1"} そして \code{"UTF-8"} をサポートする．
  エンコーディングを指定する際は一般に大・小文字の区別は無視される．

  殆どのプラットフォームでは \code{iconvlist} がサポートされるエンコーディングの
  アルファベット順のリストを提供する．他では情報は \code{iconv(5)} の
  マンページかマンページのどこかにある(しかし
  システム命令 \code{iconv} は \R が呼び出す C 関数と同じエンコーディングのセットを
  サポートしないかもしれないことを注意する)．不幸にも名前はすべてのプラットフォームを
  跨ってサポートされていることは稀である．

  返還できない \code{x} の要素(恐らくそれらが不正であるか目標のエンコーディングでは
  表示できないので)は \code{sub} が指定されていない限り \code{NA} として返される．

  \code{iconv} の殆どのバージョンは \code{to} エンコーディングに
  \samp{//TRANSLIT} を付け加えることで字訳を許す：例を見よ．
%  Most versions of \code{iconv} will allow transliteration by appending
%  \samp{//TRANSLIT} to the \code{to} encoding: see the examples.

  エンコーディング \code{"ASCII"} は受け入れられる．殆どのシステムで \code{"C"}
  と \code{"POSIX"} は ASCII の同義語である．

  \code{x} の要素のすべてのエンコーディングビット(\code{\link{Encoding}} を見よ)
  は無視される：それらはそれ以外と宣言されていてもあたかもエンコーディング \code{from}
  からのエンコーディングであるかのように翻訳される．
  \code{\link{enc2native}} と \code{\link{enc2utf8}} は宣言されたエンコーディングを
  考慮する別法である．

  \code{iconv} の実装は典型的には正当性のチェックをあまりせず，
  エンコーディング \code{from} で正当な入力をしばしば誤変換する．
}

\section{実装の詳細}{
  使用されている \code{iconv} の三つの主要な移植がある．
  Linux の C ランタイム \samp{glibc} は一つを含む．OS X, FreeBSD そして Cygwin
  を含む幾つかのプラットフォーム
  は GNU の \samp{libiconv} を提供し，追加のエンコーディングを持つこともある．
  我々は Windows では Yukihiro Nakadaira 作の \samp{win_iconv} を使っている．
  これは Windows の codepage に基づいている．
  (我々は他のシステムとの互換性のため多くのエンコーディング名を加えた．)
  これら三つは \code{iconvlist} を持ち，エンコーディング名の大・小文字を無視し
  そして \samp{//TRANSLIT} をサポートする(しかし異なる結果を持ち，
  \samp{win_iconv} に対しては \code{to = "ASCII"} を除き
  \sQuote{best fit} 戦略が使われている)．

  多くの商用 Unix は \code{iconv} の実装をもつが，
  我々が必要とするエンコーディング名をサポートするものは一つもない：
  例えば \dQuote{R Installation and Administration Manual} は
  Solaris と AIX では GNU の \samp{libiconv} のインストールを推奨している．

  他の移植もある．例えば NetBSD は Citrus プロジェクトからのものを
  使ってきている．これは \samp{//TRANSLIT} をサポートせず
  より古い FreeBSD ポートがある(そこでは \samp{libiconv} が普通使われる)：
  これらが \R で動作するかどうかは報告が無い．

  不正な入力が検出されることを信じるべきではない．
  特に \code{to = "ASCII"} に対しては，ある種の移植は 8 ビット文字を
  許しそれを未変更又は字訳して渡す．
  
  ある種の移植は興味深い追加のエンコーディングを持つ：
  例えば GNU の \samp{libiconv} は非アスキー文字に対する
  \code{\\uxxx} エスケープを使う \code{to = "C99"} を許す．
}

\section{バイトオーダーマーク}{
  最も普通には \sQuote{BOM} として知られている．

  サイズで1バイト以上の文字単位を使うエンコーディングはファイルに
  big-endian か little-endian 順序で書き込むことが出来る：
  これは最も普通には UCS-2, UTF-16 そして UTF-32/UCS-4 エンコーディングに
  適用される．ある種のシステムは Unicode 文字
  \code{U+FEFF} をそのエンコーディングのファイルの先頭に書き込む．
  恐らく UTF-8 でも同様である．こうした使用法では文字は BOM として知られており，
  入力の間そのように処理されるべきである
  (\code{\link{connection}} の\sQuote{エンコーディング}節を見よ：
  再エンコーディングされたコネクションは幾つかの BMO の特殊な処理を持つ)．
  この節の残りはこれがされておらず \code{x} が BMO で始まる場合に
  適用される．

  実装は一般に与えられた \code{from} に対する BMO を
  \code{"UCS-2"}, \code{"UTF-16"} そして \code{"UTF-32"} のどれかと
  解釈する．実装は \code{x} 中の BMO を他のエンコーディングでどのように
  扱うかの点で異なる：それらは捨て去られるかもしれず，
  文字 \code{U+FEFF} として返されるかもしれず，不正とされるかもしれない．
}
  
\value{
  もし \code{toRaw = FALSE} (既定)ならば，値は(文字列ベクトルへの変換後の)
  \code{x} と同じ長さと属性を持つ文字列ベクトルである.

  もし \code{mark = TRUE} (既定)ならば結果の要素は，
  もし \code{to} が \code{"latin1"} か \code{"UTF-8"}，又は
  もし \code{to = ""} で現在のロケールのエンコーディングが
  Latin-1 (又は Windows ではその上位集合である CP1252) 又は UTF-8 で
  あれば，宣言されたエンコーディングを持つ．


  もし \code{toRaw = TRUE} ならば，値は(文字列ベクトルへの変換後の)
  \code{x} と同じ長さと属性を持つ文字列ベクトルで，
  その要素は \code{NULL} (もし変換が失敗すれば)かバイトベクトルである．

  \code{iconvlist()} に対しては文字列ベクトル(典型的には数百の要素を持つ)
  である．
}
\note{
  普通 \sQuote{Latin 9} として知られている ISO 8859-15 エンコーディングの
  可搬性のある唯一の合理的な名前は \code{"latin-9"} である：ある種の
  プラットフォームは \code{"latin9"} をサポートするが GNU の
  \samp{libiconv} はしない．
  
  エンコード名 \code{"utf8"}, \code{"mac"} そして \code{"macroman"} は
  可搬性が無い．\code{from} と \code{to} に対する \code{"utf8"} は
  \code{iconv} により \code{"UTF-8"} に変換される(\R 3.0.3 以来)が，
  例えば \code{fileEncoding} 引数ではそうではない．\code{"macintosh"} は
  \sQuote{Mac Roman} に対する公式(そして最も広範にサポートされている)
  名前である(\url{https://en.wikipedia.org/wiki/Mac_OS_Roman})．
}

\seealso{
  \code{\link{localeToCharset}}, \code{\link{file}}.
}
\examples{
## 原則的には，すべてのシステムが iconvlist を持つわけではないので
try(utils::head(iconvlist(), n = 50))

\dontrun{
## Latin-2 から UTF-8 へ変換：glibc iconv の二つの変種．
iconv(x, "ISO_8859-2", "UTF-8")
iconv(x, "LATIN2", "UTF-8")
}

## 以下の x はどちらも latin1 で，latin1 を表示できる
## ロケールでのみ正しく表示できる．
x <- "fa\xE7ile"
Encoding(x) <- "latin1"
x
charToRaw(xx <- iconv(x, "latin1", "UTF-8"))
xx

iconv(x, "latin1", "ASCII")          #   NA
iconv(x, "latin1", "ASCII", "?")     # "fa?ile"
iconv(x, "latin1", "ASCII", "")      # "faile"
iconv(x, "latin1", "ASCII", "byte")  # "fa<e7>ile"

## 古い R のヘルプファイルから取り出す(それらは今では UTF-8 である)
x <- c("Ekstr\xf8m", "J\xf6reskog", "bi\xdfchen Z\xfcrcher")
Encoding(x) <- "latin1"
x
try(iconv(x, "latin1", "ASCII//TRANSLIT"))  # プラットフォーム依存
iconv(x, "latin1", "ASCII", sub = "byte")
## そして Windows の 'Unicode' に対しては
str(xx <- iconv(x, "latin1", "UTF-16LE", toRaw = TRUE))
iconv(xx, "UTF-16LE", "UTF-8")
}
\keyword{ character }
\keyword{ utilities }

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/iconv.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{iconv}
%\alias{iconv}
%\alias{iconvlist}
%\concept{encoding}
%\title{Convert Character Vector between Encodings}
%\description{
%  This uses system facilities to convert a character vector between
%  encodings: the \sQuote{i} stands for \sQuote{internationalization}.
%}
%\usage{
%iconv(x, from = "", to = "", sub = NA, mark = TRUE, toRaw = FALSE)
%
%iconvlist()
%}
%
%\arguments{
%  \item{x}{A character vector, or an object to be converted to a character
%    vector by \code{\link{as.character}}, or a list with \code{NULL} and
%    \code{raw} elements as returned by \code{iconv(toRaw = TRUE)}.}
%  \item{from}{A character string describing the current encoding.}
%  \item{to}{A character string describing the target encoding.}
%  \item{sub}{character string.  If not \code{NA} it is used to replace
%    any non-convertible bytes in the input.  (This would normally be a
%    single character, but can be more.)  If \code{"byte"}, the indication is
%    \code{"<xx>"} with the hex code of the byte.}
%  \item{mark}{logical, for expert use.  Should encodings be marked?}
%  \item{toRaw}{logical.  Should a list of raw vectors be returned rather
%    than a character vector?}
%}
%
%\details{
%  The names of encodings and which ones are available are
%  platform-dependent.  All \R platforms support \code{""} (for the
%  encoding of the current locale), \code{"latin1"} and \code{"UTF-8"}.
%  Generally case is ignored when specifying an encoding.
%
%  On most platforms \code{iconvlist} provides an alphabetical list of
%  the supported encodings.  On others, the information is on the man
%  page for \code{iconv(5)} or elsewhere in the man pages (but beware
%  that the system command \code{iconv} may not support the same set of
%  encodings as the C functions \R calls).  Unfortunately, the names are
%  rarely supported across all platforms.
%
%  Elements of \code{x} which cannot be converted (perhaps because they
%  are invalid or because they cannot be represented in the target
%  encoding) will be returned as \code{NA} unless \code{sub} is specified.
%
%  Most versions of \code{iconv} will allow transliteration by appending
%  \samp{//TRANSLIT} to the \code{to} encoding: see the examples.
%
%  Encoding \code{"ASCII"} is accepted, and on most systems \code{"C"}
%  and \code{"POSIX"} are synonyms for ASCII.
%
%  Any encoding bits (see \code{\link{Encoding}}) on elements of \code{x}
%  are ignored: they will always be translated as if from encoding
%  \code{from} even if declared otherwise.  \code{\link{enc2native}} and
%  \code{\link{enc2utf8}} provide alternatives which do take declared
%  encodings into account.
%
%  Note that implementations of \code{iconv} typically do not do much
%  validity checking and will often mis-convert inputs which are invalid
%  in encoding \code{from}.
%}
%
%\section{Implementation Details}{
%  There are three main implementations of \code{iconv} in use.
%  Linux's C runtime \samp{glibc} contains one.  Several platforms
%  supply GNU \samp{libiconv}, including OS X, FreeBSD and Cygwin, in
%  some cases with additional encodings.  On Windows we use a version of
%  Yukihiro Nakadaira's \samp{win_iconv}, which is based on Windows'
%  codepages.  (We have added many encoding names for compatibility
%  with other systems.)  All three have \code{iconvlist}, ignore case in
%  encoding names and support \samp{//TRANSLIT} (but with different
%  results, and for \samp{win_iconv} currently a \sQuote{best fit}
%  strategy is used except for \code{to = "ASCII"}).
%
%  Most commercial Unixes contain an implemetation of \code{iconv} but
%  none we have encountered have supported the encoding names we need:
%  the \dQuote{R Installation and Administration Manual} recommends
%  installing GNU \samp{libiconv} on Solaris and AIX, for example.
%
%  There are other implementations, e.g.\sspace{} NetBSD has used one from the
%  Citrus project (which does not support \samp{//TRANSLIT}) and there is
%  an older FreeBSD port (\samp{libiconv} is usually used there): it has
%  not been reported whether or not these work with \R.
%
%  Note that you cannot rely on invalid inputs being detected, especially
%  for \code{to = "ASCII"} where some implementations allow 8-bit
%  characters and pass them through unchanged or with transliteration.
%  
%  Some of the implementations have interesting extra encodings: for
%  example GNU \samp{libiconv} allows \code{to = "C99"} to use
%  \code{\\uxxx} escapes for non-ASCII characters.
%}
%
%\section{Byte Order Marks}{
%  most commonly known as \sQuote{BOMs}.
%
%  Encodings using character units which are more than one byte in size
%  can be written on a file in either big-endian or little-endian order:
%  this applies most commonly to UCS-2, UTF-16 and UTF-32/UCS-4
%  encodings.  Some systems will write the Unicode character
%  \code{U+FEFF} at the beginning of a file in these encodings and
%  perhaps also in UTF-8.  In that usage the character is known as a BOM,
%  and should be handled during input (see the \sQuote{Encodings} section
%  under \code{\link{connection}}: re-encoded connections have some
%  special handling of BOMs).  The rest of this section applies when this
%  has not been done so \code{x} starts with a BOM.
%
%  Implementations will generally interpret a BOM for \code{from} given
%  as one of \code{"UCS-2"}, \code{"UTF-16"} and
%  \code{"UTF-32"}.  Implementations differ in how they treat BOMs in
%  \code{x} in other \code{from} encodings: they may be discarded,
%  returned as character \code{U+FEFF} or regarded as invalid.
%}
%  
%\value{
%  If \code{toRaw = FALSE} (the default), the value is a character vector
%  of the same length and the same attributes as \code{x} (after
%  conversion to a character vector).
%
%  If \code{mark = TRUE} (the default) the elements of the result have a
%  declared encoding if \code{to} is \code{"latin1"} or \code{"UTF-8"},
%  or if \code{to = ""} and the current locale's encoding is detected as
%  Latin-1 (or its superset CP1252 on Windows) or UTF-8.
%
%  If \code{toRaw = TRUE}, the value is a vector of the same length and
%  the same attributes as \code{x} whose elements are either \code{NULL}
%  (if conversion fails) or a raw vector.
%
%  For \code{iconvlist()}, a character vector (typically of a few hundred
%  elements).
%}
%\note{
%  The only reasonably portable name for the ISO 8859-15 encoding,
%  commonly known as \sQuote{Latin 9}, is \code{"latin-9"}: some
%  platforms support \code{"latin9"} but GNU \samp{libiconv} does not.
%  
%  Encoding names \code{"utf8"}, \code{"mac"} and \code{"macroman"} are
%  not portable.  \code{"utf8"} is converted to \code{"UTF-8"} for
%  \code{from} and \code{to} (as from \R 3.0.3) by \code{iconv}, but not
%  for e.g.\sspace{}\code{fileEncoding} arguments.  \code{"macintosh"} is
%  the official (and most widely supported) name for \sQuote{Mac Roman}
%  (\url{https://en.wikipedia.org/wiki/Mac_OS_Roman}).
%}
%
%\seealso{
%  \code{\link{localeToCharset}}, \code{\link{file}}.
%}
%\examples{
%## In principle, as not all systems have iconvlist
%try(utils::head(iconvlist(), n = 50))
%
%\dontrun{
%## convert from Latin-2 to UTF-8: two of the glibc iconv variants.
%iconv(x, "ISO_8859-2", "UTF-8")
%iconv(x, "LATIN2", "UTF-8")
%}
%
%## Both x below are in latin1 and will only display correctly in a
%## locale that can represent and display latin1.
%x <- "fa\xE7ile"
%Encoding(x) <- "latin1"
%x
%charToRaw(xx <- iconv(x, "latin1", "UTF-8"))
%xx
%
%iconv(x, "latin1", "ASCII")          #   NA
%iconv(x, "latin1", "ASCII", "?")     # "fa?ile"
%iconv(x, "latin1", "ASCII", "")      # "faile"
%iconv(x, "latin1", "ASCII", "byte")  # "fa<e7>ile"
%
%## Extracts from old R help files (they are nowadays in UTF-8)
%x <- c("Ekstr\xf8m", "J\xf6reskog", "bi\xdfchen Z\xfcrcher")
%Encoding(x) <- "latin1"
%x
%try(iconv(x, "latin1", "ASCII//TRANSLIT"))  # platform-dependent
%iconv(x, "latin1", "ASCII", sub = "byte")
%## and for Windows' 'Unicode'
%str(xx <- iconv(x, "latin1", "UTF-16LE", toRaw = TRUE))
%iconv(xx, "UTF-16LE", "UTF-8")
%}
%\keyword{ character }
%\keyword{ utilities }
%
\encoding{UTF8}
