% File src/library/base/man/logical.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2011 R Core Team
% Distributed under GPL 2 or later

\name{logical}
\alias{logical}
\alias{as.logical}
\alias{as.logical.factor}
\alias{is.logical}
\alias{TRUE}
\alias{FALSE}
\alias{T}
\alias{F}
\title{Logical Vectors}
\description{
  型 \code{"logical"} のオブジェクトを作る，また検査する，
  そして基本論理定数．
}
\usage{
TRUE
FALSE
T; F

logical(length = 0)
as.logical(x, \dots)
is.logical(x)
}
\details{
  \code{TRUE} と \code{FALSE} は論理定数を表す \R 言語の予約後であるが，
  \code{T} と \code{F} は初期値がこれらに設定される大局的変数である．
  これら4種類は全て \code{logical(1)} ベクトルである．

  論理値ベクトルは数値が必要となる文脈では整数ベクトルに強制変換される．
  \code{TRUE} は \code{1L} に，\code{FALSE} は \code{0L} に，
  そして \code{NA} は \code{NA_integer_} にマップされる．
}
\arguments{
  \item{length}{必要な長さを指定する非負整数．
    倍精度値は整数に強制変換される：
    長さ1以外の引数を与えるとエラーになる．}
  \item{x}{変換又は検査されるオブジェクト．}
  \item{\dots}{他のメソッドへ・から渡される追加引数．}
}
\value{
  \code{logical} は指定された長さの論理値ベクトルを作る．
  ベクトルの各要素は \code{FALSE} に等しい．

  \code{as.logical} はその引数を論理値型に変換しようと試みる．
  \code{\link{factor}} に対しては，これは水準
  (ラベル) を使う．\code{\link{as.vector}} と同様に名前を含む属性は剥ぎ取られる．
  文字列 \code{"T"}, \code{"TRUE"}, \code{"True"}, \code{"true"} は真，
  \code{"F"}, \code{"FALSE"}, \code{"False"}, \code{"false"} は偽，
  そして他の全ては \code{NA} と見做される．

  \code{is.logical} はその引数が論理値型か否かに応じて \code{TRUE} か
  \code{FALSE} を返す．
}
\seealso{
  他の論理定数 \code{\link{NA}}．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\keyword{classes}
\keyword{logic}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/logical.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2011 R Core Team
%% Distributed under GPL 2 or later
%
%\name{logical}
%\alias{logical}
%\alias{as.logical}
%\alias{as.logical.factor}
%\alias{is.logical}
%\alias{TRUE}
%\alias{FALSE}
%\alias{T}
%\alias{F}
%\title{Logical Vectors}
%\description{
%  Create or test for objects of type \code{"logical"}, and the basic
%  logical constants.
%}
%\usage{
%TRUE
%FALSE
%T; F
%
%logical(length = 0)
%as.logical(x, \dots)
%is.logical(x)
%}
%\details{
%  \code{TRUE} and \code{FALSE} are \link{reserved} words denoting logical
%  constants in the \R language, whereas \code{T} and \code{F} are global
%  variables whose initial values set to these.  All four are
%  \code{logical(1)} vectors.
%
%  Logical vectors are coerced to integer vectors in contexts where a
%  numerical value is required, with \code{TRUE} being mapped to
%  \code{1L}, \code{FALSE} to \code{0L} and \code{NA} to \code{NA_integer_}.
%}
%\arguments{
%  \item{length}{A non-negative integer specifying the desired length.
%    Double values will be coerced to integer:
%    supplying an argument of length other than one is an error.}
%  \item{x}{object to be coerced or tested.}
%  \item{\dots}{further arguments passed to or from other methods.}
%}
%\value{
%  \code{logical} creates a logical vector of the specified length.
%  Each element of the vector is equal to \code{FALSE}.
%
%  \code{as.logical} attempts to coerce its argument to be of logical
%  type.  For \code{\link{factor}}s, this uses the \code{\link{levels}}
%  (labels).  Like \code{\link{as.vector}} it strips attributes including
%  names.  Character strings \code{c("T", "TRUE", "True", "true")} are
%  regarded as true, \code{c("F", "FALSE", "False", "false")} as false,
%  and all others as \code{NA}.
%
%  \code{is.logical} returns \code{TRUE} or \code{FALSE} depending on
%  whether its argument is of logical type or not.
%}
%\seealso{
%  \code{\link{NA}}, the other logical constant.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\keyword{classes}
%\keyword{logic}
%
\encoding{UTF8}
