% File src/library/base/man/range.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{range}
\alias{range}
\alias{range.default}
\title{Range of Values}
\usage{
range(\dots, na.rm = FALSE)

\method{range}{default}(\dots, na.rm = FALSE, finite = FALSE)
}
\arguments{
  \item{\dots}{任意の数値もしくは文字オブジェクト．}
  \item{na.rm}{論理値で，\code{\link{NA}} を除外するかどうかを指示する．}
  \item{finite}{論理値で，全ての有限でない値を除外するかどうかを指示する．}
}
\description{
  \code{range} は与えられた全ての引数の最大値と最小値のベクトルを返す．
}
\details{
  \code{range} は総称的な関数である：それに対するメソッドを直接または
  \code{\link[=S3groupGeneric]{Summary}} グループ総称関数の一部として
  定義できる．これが正しく動作するためには引数 \code{\dots} は名前がなく，
  選択適用はその第一引数について行われるべきである．

  もし \code{na.rm} が \code{FALSE} ならば，任意の引数中の値 \code{NA}
  と \code{NaN} は返り値を \code{NA} 値にする．さもなければ
  \code{NA} 値は無視される．

  もし \code{finite} が \code{TRUE} ならば，全ての有限値の
  最少と最大が計算される，つまり
  \code{finite = TRUE} は \code{na.rm = TRUE} を含む．

  (\code{NA} を除いた後)空でない引数がない場合には特別な状況が起こる，
  \code{\link{min}} を見よ．% Extremes.Rd
}
\section{S4 methods}{
  これは S4 \code{\link[=S4groupGeneric]{Summary}}
  グループメソッドの一部である．それに対するメソッドはシグネチャ
  \code{x, \dots, na.rm} を使わねばならない．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\seealso{
  \code{\link{min}}, \code{\link{max}}.

  パッケージ \pkg{grDevices} 中のユーテリティ \code{\link{extendrange}()}．
}
\examples{
(r.x <- range(stats::rnorm(100)))
diff(r.x) # 標本範囲

x <- c(NA, 1:3, -1:1/0); x
range(x)
range(x, na.rm = TRUE)
range(x, finite = TRUE)
}
\keyword{univar}
\keyword{arith}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/range.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{range}
%\alias{range}
%\alias{range.default}
%\title{Range of Values}
%\usage{
%range(\dots, na.rm = FALSE)
%
%\method{range}{default}(\dots, na.rm = FALSE, finite = FALSE)
%}
%\arguments{
%  \item{\dots}{any \code{\link{numeric}} or character objects.}
%  \item{na.rm}{logical, indicating if \code{\link{NA}}'s should be
%    omitted.}
%  \item{finite}{logical, indicating if all non-finite elements should
%    be omitted.}
%}
%\description{
%  \code{range} returns a vector containing the minimum and maximum of
%  all the given arguments.
%}
%\details{
%  \code{range} is a generic function: methods can be defined for it
%  directly or via the \code{\link[=S3groupGeneric]{Summary}} group generic.
%  For this to work properly, the arguments \code{\dots} should be
%  unnamed, and dispatch is on the first argument.
%
%  If \code{na.rm} is \code{FALSE}, \code{NA}
%  and \code{NaN} values in any of the arguments will cause \code{NA} values
%  to be returned, otherwise \code{NA} values are ignored.
%
%  If \code{finite} is \code{TRUE}, the minimum
%  and maximum of all finite values is computed, i.e.,
%  \code{finite = TRUE} \emph{includes} \code{na.rm = TRUE}.
%
%  A special situation occurs when there is no (after omission
%  of \code{NA}s) nonempty argument left, see \code{\link{min}}.% Extremes.Rd
%}
%\section{S4 methods}{
%  This is part of the S4 \code{\link[=S4groupGeneric]{Summary}}
%  group generic.  Methods for it must use the signature
%  \code{x, \dots, na.rm}.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\seealso{
%  \code{\link{min}}, \code{\link{max}}.
%
%  The \code{\link{extendrange}()} utility in package \pkg{grDevices}.
%}
%\examples{
%(r.x <- range(stats::rnorm(100)))
%diff(r.x) # the SAMPLE range
%
%x <- c(NA, 1:3, -1:1/0); x
%range(x)
%range(x, na.rm = TRUE)
%range(x, finite = TRUE)
%}
%\keyword{univar}
%\keyword{arith}
%
\encoding{UTF8}
