% File src/library/base/man/sink.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{sink}
\alias{sink}
\alias{sink.number}
\concept{tee}
\title{Send R Output to a File}
\usage{
sink(file = NULL, append = FALSE, type = c("output", "message"),
     split = FALSE)

sink.number(type = c("output", "message"))
}
\arguments{
  \item{file}{書き込み可能なコネクション，又は
    書き込みがされるファイルの名前を与える文字列，もしくは
    シンクを停止するには \code{NULL}．}
  \item{append}{論理値．もし \code{TRUE} なら出力は \code{file} に
    付け加えられる；さもなければ \code{file} の内容を書き換える．}
  \item{type}{文字列．出力ストリームかメッセージストリーム．
    名前は部分マッチングされ短縮化できる．}
  \item{split}{論理値：もし \code{TRUE} なら，
    Unix プログラム \code{tee} の様に，出力は新しいシンクと
    現在の出力ストリームに送られる．}
}
\description{
  \code{sink} は \R 出力をコネクションに転送する．

  \code{sink.number()} は幾つの転送が使われているかを報告する．

  \code{sink.number(type = "message")} は現在エラーメッセージのために
  使われているコネクションの数を報告する．
}
\details{
  \code{sink} は \R の出力を転送する．もし \code{file} が文字列ならば
  その名前を持つファイルコネクションが転送の間確立される．

  正常な \R 出力(コネクション \code{\link{stdout}} への)は
  既定の \code{type = "output"} で転送される．プロンプトと(殆どの)
  メッセージはコンソールに現れ続ける．
  \code{\link{stderr}()} に送られたメッセージ(\code{\link{message}},
  \code{\link{warning}} そして \code{\link{stop}} からのものを含む)は
  \code{sink(type = "message")} で転送される(下を見よ)．

  \code{sink()} 又は \code{sink(file = NULL)} は最後の(指定のタイプの)
  転送を停止する．正常な出力に対する転送のスタックがあり，従って
  出力は先の転送(もしあれば)に戻る．
  スタックは最大 21 コネクション(20 転送)である．

  もし \code{file} がコネクションならば，それは必要に応じて開かれ
  (モード \code{"wt"} で) そしてそれが転送のスタックから取り除かれると閉じられる．

  \code{split = TRUE} は \R 出力(\code{Rvprintf} を使い)と
  \code{\link{writeLines}} からの既定の出力だけを分割する：
  それは \code{\link{stdout}()} に送られるかもしれない全ての出力を
  分割しない．

  メッセージストリームのシンクは細心の注意でなされるべきである．
  ストリームに対する \code{file} は既に開かれているコネクションで
  無ければならず，そしてコネクションのスタックは無い．

  もし \code{file} が文字列ならば，ファイルが現在のエンコーディングを使い
  開かれる．もし別のエンコーディングを使いたければ(例えば，UTF-8 で
  保存された文字列を表現するために)
  \code{\link{file}} コネクションを使う --- しかし \R 出力を生み出すある種の
  方法はそうした文字列を既に現在のエンコーディングに変換している．
}
\value{
  \code{sink} は \code{NULL} を返す．

  \code{sink.number()} に対しては出力の転送の数 (0, 1, 2, \dots)．

  \code{sink.number("message")} に対してはメッセージに使われている
  コネクションの数．もし転送が使われていなければ 2．
}
\section{警告}{
  \code{sink} 用に開かれたコネクションを何にもせよ他の目的に使ってはならない．
  そうしたものを不注意に閉じるとソフトウェアは停止するであろう．

  メッセージストリームは，ソースコードの実装と従ってその落とし穴を理解して
  いない限りシンクすべきではない．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.

  Chambers, J. M. (1998)
  \emph{Programming with Data.  A Guide to the S Language}.
  Springer.
}
\seealso{\code{\link{capture.output}}}
\examples{
sink("sink-examp.txt")
i <- 1:10
outer(i, i, "*")
sink()
unlink("sink-examp.txt")
\donttest{
## 全ての出力をファイルに捕捉する．
zz <- file("all.Rout", open = "wt")
sink(zz)
sink(zz, type = "message")
try(log("a"))
## コンソールに戻る
sink(type = "message")
sink()
file.show("all.Rout")
}}
\keyword{file}
\keyword{connection}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/sink.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{sink}
%\alias{sink}
%\alias{sink.number}
%\concept{tee}
%\title{Send R Output to a File}
%\usage{
%sink(file = NULL, append = FALSE, type = c("output", "message"),
%     split = FALSE)
%
%sink.number(type = c("output", "message"))
%}
%\arguments{
%  \item{file}{a writable \link{connection} or a character string naming the
%    file to write to, or \code{NULL} to stop sink-ing.}
%  \item{append}{logical.  If \code{TRUE}, output will be appended to
%    \code{file}; otherwise, it will overwrite the contents of
%    \code{file}.}
%  \item{type}{character string.  Either the output stream or the messages
%    stream.  The name will be partially matched so can be abbreviated.}
%  \item{split}{logical: if \code{TRUE}, output will be sent to the new
%    sink and to the current output stream, like the Unix program \code{tee}.}
%}
%\description{
%  \code{sink} diverts \R output to a connection.
%
%  \code{sink.number()} reports how many diversions are in use.
%
%  \code{sink.number(type = "message")} reports the number of the
%  connection currently being used for error messages.
%}
%\details{
%  \code{sink} diverts \R output to a connection.  If \code{file} is a
%  character string, a file connection with that name will be established
%  for the duration of the diversion.
%
%  Normal \R output (to connection \code{\link{stdout}}) is diverted by
%  the default \code{type = "output"}.  Only prompts and (most)
%  messages continue to appear on the console.  Messages sent to
%  \code{\link{stderr}()} (including those from \code{\link{message}},
%  \code{\link{warning}} and \code{\link{stop}}) can be diverted by
%  \code{sink(type = "message")} (see below).
%
%  \code{sink()} or \code{sink(file = NULL)} ends the last diversion (of
%  the specified type).  There is a stack of diversions for normal
%  output, so output reverts to the previous diversion (if there was
%  one).  The stack is of up to 21 connections (20 diversions).
%
%  If \code{file} is a connection it will be opened if necessary (in
%  \code{"wt"} mode) and closed once it is removed from the stack of
%  diversions.
%
%  \code{split = TRUE} only splits \R output (via \code{Rvprintf}) and
%  the default output from \code{\link{writeLines}}: it does not split
%  all output that might be sent to \code{\link{stdout}()}.
%
%  Sink-ing the messages stream should be done only with great care.
%  For that stream \code{file} must be an already open connection, and
%  there is no stack of connections.
%
%  If \code{file} is a character string, the file will be opened using
%  the current encoding.  If you want a different encoding (e.g., to
%  represent strings which have been stored in UTF-8), use a
%  \code{\link{file}} connection --- but some ways to produce \R output
%  will already have converted such strings to the current encoding.
%}
%\value{
%  \code{sink} returns \code{NULL}.
%
%  For \code{sink.number()} the number (0, 1, 2, \dots) of diversions of
%  output in place.
%
%  For \code{sink.number("message")} the connection number used for
%  messages, 2 if no diversion has been used.
%}
%\section{Warning}{
%  Do not use a connection that is open for \code{sink} for any other
%  purpose.  The software will stop you closing one such inadvertently.
%
%  Do not sink the messages stream unless you understand the source code
%  implementing it and hence the pitfalls.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%
%  Chambers, J. M. (1998)
%  \emph{Programming with Data.  A Guide to the S Language}.
%  Springer.
%}
%\seealso{\code{\link{capture.output}}}
%\examples{
%sink("sink-examp.txt")
%i <- 1:10
%outer(i, i, "*")
%sink()
%unlink("sink-examp.txt")
%\donttest{
%## capture all the output to a file.
%zz <- file("all.Rout", open = "wt")
%sink(zz)
%sink(zz, type = "message")
%try(log("a"))
%## back to the console
%sink(type = "message")
%sink()
%file.show("all.Rout")
%}}
%\keyword{file}
%\keyword{connection}
%
\encoding{UTF8}
