% File src/library/base/man/system.time.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2011 R Core Team
% Distributed under GPL 2 or later

\name{system.time}
\title{CPU Time Used}
\usage{
system.time(expr, gcFirst = TRUE)
unix.time(expr, gcFirst = TRUE)
}
\alias{system.time}
\alias{unix.time}
\arguments{
  \item{expr}{計時する適正な \R 表現式．}
  \item{gcFirst}{論理値：計時の前にガベージコレクションを実行すべきか?
  既定は \code{TRUE}．}
}
\description{\code{expr} が使用した CPU (及びその他の)時間．
}
\details{
  \code{system.time} は関数 \code{\link{proc.time}} を呼び出し，
  \code{expr} を評価し，そしてそれからもう一度 \code{proc.time} を呼び出し，
  二つの \code{proc.time} 呼び出しの差を返す．

  \code{unix.time} は S との互換性ためにある \code{system.time} の別名である．

  同じ表現式の評価の計時は，評価がガベージコレクションを惹き起こすかどうかで
  非常に変化する．\code{gcFirst} が \code{TRUE} ならガベージコレクション
  (\code{\link{gc}})が \code{expr} の評価の直前に実行される．
  これは普通より一貫性のある計時結果を与える．
}
\value{
  クラス \code{"proc_time"} のオブジェクト：詳細は
  \code{\link{proc.time}} を見よ．
}
\seealso{
  時系列向きの \code{\link{proc.time}}, \code{\link{time}}．
  
  現在の日付と時刻を得るためには \code{\link{Sys.time}}．
}
\examples{
require(stats)
\donttest{system.time(for(i in 1:100) mad(runif(1000)))}
\dontrun{
exT <- function(n = 10000) {
  # 目的：system.time が操作するかどうかテスト； n：ループサイズ
  system.time(for(i in 1:n) x <- mean(rt(1000, df = 4)))
}
#-- 次のどれかを中断しようとする(Ctrl-C / Escape を使う)：
exT()                 #- 2.5GHz Xeon で約 4 秒
system.time(exT())    #~ +/- 同じ
}}
\keyword{utilities}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/system.time.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2011 R Core Team
%% Distributed under GPL 2 or later
%
%\name{system.time}
%\title{CPU Time Used}
%\usage{
%system.time(expr, gcFirst = TRUE)
%unix.time(expr, gcFirst = TRUE)
%}
%\alias{system.time}
%\alias{unix.time}
%\arguments{
%  \item{expr}{Valid \R expression to be timed.}
%  \item{gcFirst}{Logical - should a garbage collection be performed
%    immediately before the timing?  Default is \code{TRUE}.}
%}
%\description{Return CPU (and other) times that \code{expr} used.
%}
%\details{
%  \code{system.time} calls the function \code{\link{proc.time}},
%  evaluates \code{expr}, and then calls \code{proc.time} once more,
%  returning the difference between the two \code{proc.time} calls.
%
%  \code{unix.time} is an alias of \code{system.time}, for
%  compatibility with S.
%
%  Timings of evaluations of the same expression can vary considerably
%  depending on whether the evaluation triggers a garbage collection.  When
%  \code{gcFirst} is \code{TRUE} a garbage collection (\code{\link{gc}})
%  will be performed immediately before the evaluation of \code{expr}.
%  This will usually produce more consistent timings.
%}
%\value{
%  A object of class \code{"proc_time"}: see
%  \code{\link{proc.time}} for details.
%}
%\seealso{
%  \code{\link{proc.time}}, \code{\link{time}} which is for time series.
%  
%  \code{\link{Sys.time}} to get the current date & time.
%}
%\examples{
%require(stats)
%\donttest{system.time(for(i in 1:100) mad(runif(1000)))}
%\dontrun{
%exT <- function(n = 10000) {
%  # Purpose: Test if system.time works ok;   n: loop size
%  system.time(for(i in 1:n) x <- mean(rt(1000, df = 4)))
%}
%#-- Try to interrupt one of the following (using Ctrl-C / Escape):
%exT()                 #- about 4 secs on a 2.5GHz Xeon
%system.time(exT())    #~ +/- same
%}}
%\keyword{utilities}
%