% File src/library/base/man/timezones.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{timezones}
\alias{Sys.timezone}
\alias{OlsonNames}
\alias{timezone}
\alias{timezones}
\alias{time zone}
\alias{time zones}
\alias{TZ}
\alias{TZDIR}

\title{Time Zones}
\description{
  \R のタイムゾーンに関する情報．\code{Sys.timezone} は現在の
  タイムゾーンの名前を返す．
}

\usage{
Sys.timezone(location = TRUE)

OlsonNames()
}

\arguments{
  \item{location}{論理値：Olson/IANA データベースで使われているような
    位置名を見つけようとするか?
    (下の\sQuote{タイムゾーン名}を見よ．)}
}

\details{
  タイムゾーンはシステム固有のトピックであるが，最近ではほとんどすべての \R
  プラットフォームは同じような基礎コードを使う．
  これは Linux, OS X, Solaris,
  AIX, FreeBSD, Sun Java >= 1.4 そして Tcl >= 8.5 で使われ，
  Windows では \R と共にインストールされる．
  不幸にも実装には多くのシステム固有のエラーがある．
  Unix 風システムと Windows で \R 自体のコードを使うことが出来る：
  これは OS X では既定であり Solaris に対しては推奨される．

  タイムゾーンを環境変数 \env{TZ} で設定できる：適当な値は節\sQuote{タイムゾーン名}を見よ．
  \code{Sys.timezone()} はもし設定されていれば \env{TZ} の値を返す
  (幾つかの OS ではそれは常に設定されている)，さもなければそれは
  もし \env{TZ} に対して設定されていれば現在のタイムゾーンである値を
  探そうと試みる．
  これは一般には可能ではなく，Windows の \code{Sys.timezone(FALSE)} は現在の時間に
  対して使われる省略形を探す．

  もし \env{TZ} が設定されているが空か不正ならば，殆どのプラットフォームは
  既定で俗に \samp{GMT} として知られているタイムゾーン  \samp{UTC} を使う
  (\url{https://en.wikipedia.org/wiki/Coordinated_Universal_Time} を見よ)．
  ある種の，しかし全てではない，プラットフォームでは不正な
  タイムゾーンに対して警告を出す．)

  タイムゾーンは19世紀半ばまで使われることはなく，20世紀までは広く採用されず
  ，そして\emph{DST(daylight saving time)} (\emph{サマータイム}としても
  知られている)は最初20世紀初期(最も広範囲には1916年)に導入された．
  過去百年の間に位置は主要なタイムゾーンとの連携を変化しており，
  様々な年に廃止(導入)され，使用 DTS 規則は後で変更されたり全く
  変更されなかったりする．
  
  \code{POSIXct} の非常に普通の実装は符号付き整数としてであり，
  従って1901年の終わりにまでしか遡れない：
  そうしたシステムでは \R はそれ以前は1902年当時と同じタイムゾーンにあったと仮定する．
  世界の殆どは1902年にはタイムゾーンを採用していなかったが
  (したがって経度に基づく局所\sQuote{平均時間}を使っていた)
  それ以前にタイムゾーンが変更されていた地域も少しある．
  64ビット表現が普通になってきている；不幸なことに
  ある種の OS (特に OS X) ではデータベース情報は範囲
  1901--2038 でだけ得られ，端の年では不完全である．
}

\value{
  \code{Sys.timezone} は OS 固有の文字列を返す．
  \code{NA} や空の文字列(これはある種の OS では \samp{UTC} を意味する)の
  可能性がある．
  既定の \code{location = TRUE} では \code{"Europe/London"} の
  ような位置であり，確認が出来る．\code{location = FALSE} では
  これは \code{"EST"} 又は Windows では \code{"CEST"} のような
  省略形かもしれない．

  \code{OlsonNames} は文字列ベクトルを返す．
}

\section{タイムゾーン名}{
  名前 \code{"UTC"} とその同義語 \code{"GMT"} は全てのプラットフォームで受け入れられる．

  OS がそれらの適正なタイムゾーンをどこで解説しているかは曖昧なことがある．
  C 関数 \code{tzset} のヘルプは役に立つが，しかしそれも不正確なことがある．
  面倒な POSIX の仕様(
  \url{http://pubs.opengroup.org/onlinepubs/9699919799/basedefs/V1_chap08.html#tag_08}
  にある環境変数 \env{TZ} の元にリストされている)があり，
  これはしばしば部分的にサポートされているが，
  他のより親切なタイムゾーンの指定法がある．

  ほとんどすべての \R プラットフォームは
  最初 Arthur David Olson によりそして今は IANA で保守されている
  タイムゾーンのデータベースを利用している．
  そこではタイムゾーンの好まれる参照方法は位置(典型的には都市)を使うものである．
  例えば \code{Europe/London}, 伝統的な \code{America/Los_Angeles},
  \code{Pacific/Easter}．\code{EST5EDT} や \code{GB} のような幾つかの
  表記もまた許される．
  (これらの表記の幾つかは期待されるものと異なる可能性があることを注意する：
  特に \code{EST} はカナダで使われるサマータイム無しのタイムゾーンで，
  \code{EST5EDT} でも(オーストラリアの) Eastern Standard Time でもない.)
  この指定は蓄積されたゾーン情報を与えるファイルへのパス
  の先頭にオプションのコロンを持っても良い
  (そして上の例は全てシステム固有の位置のファイルである)．より詳細は
  \url{http://www.twinsun.com/tz/tz-link.htm} と参考文献を見よ．
  便宜上1970年からユニークなタイムゾーン履歴を持つ地域はデータベース中で
  特別な名前を持つが，異なる過去の履歴を持つものはそうではない．
  各タイムゾーンは時間の整形で使われる一つ又は複数
  (DST に対しては二番目)の\emph{省略形}を持つ．

  使用される省略形は年と共に変化してきている：例えばフランスは
  1891年から1911年は \samp{PMT} (\sQuote{パリ平均時間}) を使い，
  \samp{WET/WEST} up to 1940 and \samp{CET/CEST} from 1946.
  (ほとんどすべてのタイムゾーンでは1970年以来安定している．)
  POSIX 標準はタイムゾーン毎に一つ又は二つの省略形を認めるので，
  現在の省略形が昔使われていたものである可能性がある．
  
  関数 \code{OlsonNames} は現在のシステムにある Olson/IANA 
  データベースが知っている名前を返す．ファイルシステム中のシステム
  固有の位置は変化する，例えば \sspace{}\file{/usr/share/zoneinfo}
  (Linux, OS X, FreeBSD), \file{/usr/share/lib/zoneinfo} (Solaris, AIX),
  \ldots 等．そのディレクトリの下にタイムゾーン名(しかし例えば \code{EST5EDT}
  は無い)として知られている位置をリストする
  \file{zone.tab} のような名前のファイルが恐らくある: これは
  \code{OlsonNames} で読み込まれる．  
  \url{https://en.wikipedia.org/wiki/Zone.tab} も見よ．

  \R がオプション \option{--with-internal-tzcode} 付きでコンフィギュア
  (OS X と Windows では既定：Solaris では推奨)されると，
  \code{file.path(R.home("share"), "zoneinfo")} にあるデータベースが
  既定で使われる：そのディレクトリ中のファイル
  \file{VERSION} はバージョンを示す．環境変数 \env{TZDIR} は
  異なった \file{zoneinfo} ディレクトリを指示することに使える：
  これはまたある種の OS，例えば \sspace{}Linux，ではネイティブなサービスとして
  サポートされている．
#ifdef windows

  Windows が考えるところの現在のタイムゾーンを位置にマップする試みが
  なされている．これはバージョン
  \url{http://unicode.org/repos/cldr/trunk/common/supplemental/windowsZones.xml}
  に従っており，Windows のレジストリとドキュメントから導かれた値を用いる．
  これはセッション中で任意の暦日・時刻を使う前に環境変数 \code{TZ} を
  設定することで上書き出来る．
#endif

  殆どのプラットフォームは \samp{GMT+n} と \samp{GMT-n} の形式のタイムゾーンを
  サポートしている．これは UTC からの固定オフセットを意味している(従って DST は無い)．
  予想外かもしれないが(しかし \samp{PST8PDT} のような名前とは一貫性がある)，
  負のオフセットは UTC の前(西側)を意味し，正のオフセットは
  UTC の後(東側)を意味する．
  
  法定のタイムゾーンの制定のすぐ前には殆どの人々は彼ら(又は近くの町の)の経度に
  基礎を持つ時間を使っており，\sQuote{ローカル平均時間}と呼ばれデータベース中では
  \samp{LMT} と省略される：多くの都市では標準時間に移る前には
  これが特定の名前で成文化されていた．
  例えばパリは1891年にその LMT を\sQuote{パリ平均時間}としており(フランス本土を通じて
  で使われた)そして1911年に \samp{GMT+0} に移行した．
}

\note{
  2007年以来，エネルギー節約を狙ったDSTへの移行のタイミングの変更
  に関する相当な混乱があった．これらはしばしば短い通告であり
  タイムゾーンのデータベースは更新され無い可能性がある．
  (モロッコは2013年にDSTの終了時期の変更を\emph{前日}に布告し，
  北朝鮮は2015年に変更に関する不正確な情報を一週間前に与えた．)

  大・小文字を区別しないファイルシステムを持つプラットフォームでは，
  タイムゾーン名は大・小文字を区別しない．
  他のプラットフォームでは区別したりしなかったりするため，
  例えば \code{"gmt"} はある種のプラットフォームでは適正で，他の
  プラットフォームではそうではない．

  置き換えがされている場合を除き, タイムゾーンの操作は OS のサービス
  であり，置き換えがされていても第三者のデータベースが使われ
  更新出来る(\sQuote{タイムゾーン名}の節を見よ)．
  不正確な結果は決して \R の問題ではないので，それについて \R を
  責めることが無いようにお願いしたい．
}
% Unlike Tony Plate and John Pfuntner

\seealso{
  \code{\link{Sys.time}}, \code{\link{as.POSIXlt}}.

  広範囲なリンクのセットについては \url{https://en.wikipedia.org/wiki/Time_zone} と
  \url{https://www.twinsun.com/tz/tz-link.htm}．
}

\examples{
Sys.timezone()

str(OlsonNames()) ## 数百の名前
}
\keyword{utilities}
\keyword{chron}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/timezones.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{timezones}
%\alias{Sys.timezone}
%\alias{OlsonNames}
%\alias{timezone}
%\alias{timezones}
%\alias{time zone}
%\alias{time zones}
%\alias{TZ}
%\alias{TZDIR}
%
%\title{Time Zones}
%\description{
%  Information about time zones in \R.  \code{Sys.timezone} returns
%  the name of the current time zone.
%}
%
%\usage{
%Sys.timezone(location = TRUE)
%
%OlsonNames()
%}
%
%\arguments{
%  \item{location}{logical: should an attempt be made to find the
%    location name as used in the Olson/IANA database?
%    (See \sQuote{Time zone names} below.)}
%}
%
%\details{
%  Time zones are a system-specific topic, but these days almost all \R
%  platforms use similar underlying code, used by Linux, OS X, Solaris,
%  AIX, FreeBSD, Sun Java >= 1.4 and Tcl >= 8.5, and installed with \R on
%  Windows.  Unfortunately there are many system-specific errors in the
%  implementations.  It is possible to use \R's own version of the code
%  on Unix-alikes as well as on Windows: this is the default for OS X and
%  recommended for Solaris.
%
%  It should be possible to set the time zone via the environment
%  variable \env{TZ}: see the section on \sQuote{Time zone names} for
%  suitable values.  \code{Sys.timezone()} will return the value of
%  \env{TZ} if set (and on some OSes it is always set), otherwise it will
%  try to retrieve a value which if set for \env{TZ} would give the
%  current time zone.  This is not in general possible, and
%  \code{Sys.timezone(FALSE)} on Windows will retrieve the abbreviation
%  used for the current time.
%
%  If \env{TZ} is set but empty or invalid, most platforms default to
%  \samp{UTC}, the time zone colloquially known as \samp{GMT} (see
%  \url{https://en.wikipedia.org/wiki/Coordinated_Universal_Time}).  (Some
%  but not all platforms will give a warning for invalid time zones.)
%
%  Time zones did not come into use until the second half of the
%  nineteenth century and were not widely adopted until the twentieth,
%  and \emph{daylight saving time} (DST, also known as \emph{summer
%  time}) was first introduced in the early twentieth century, most
%  widely in 1916. Over the last 100 years places have changed their
%  affiliation between major time zones, have opted out of (or in to) DST
%  in various years or adopted DST rule changes late or not at all.
%  
%  A quite common system implementation of \code{POSIXct} is as
%  signed 32-bit integers and so only goes back to the end of 1901: on
%  such systems \R assumes that dates prior to that are in the same time
%  zone as they were in 1902.  Most of the world had not adopted time
%  zones by 1902 (so used local \sQuote{mean time} based on longitude)
%  but for a few places there had been time-zone changes before then.
%  64-bit representations are becoming common; unfortunately on some
%  64-bit OSes (notably OS X) the database information is only available
%  for the range 1901--2038, and incompletely for the end years.
%}
%
%\value{
%  \code{Sys.timezone} returns an OS-specific character string, possibly
%  \code{NA} or an empty string (which on some OSes means \samp{UTC}).
%  For the default \code{location = TRUE} this will be a location such as
%  \code{"Europe/London"} if one can be ascertained.  For \code{location
%  = FALSE} this may be an abbreviation such as \code{"EST"} or
%  \code{"CEST"} on Windows.
%
%  \code{OlsonNames} returns a character vector.
%}
%
%\section{Time zone names}{
%  Names \code{"UTC"} and its synonym \code{"GMT"} are accepted on all
%  platforms.
%
%  Where OSes describe their valid time zones can be obscure.  The help
%  for the C function \code{tzset} can be helpful, but it can also be
%  inaccurate.  There is a cumbersome POSIX specification (listed under
%  environment variable \env{TZ} at
%  \url{http://pubs.opengroup.org/onlinepubs/9699919799/basedefs/V1_chap08.html#tag_08}),
%  which is often at least partially supported, but there are other more
%  user-friendly ways to specify time zones.
%
%  Almost all \R platforms make use of a time-zone database originally
%  compiled by Arthur David Olson and now managed by IANA, in which the
%  preferred way to refer to a time zone is by a location (typically of a
%  city), e.g., \code{Europe/London}, \code{America/Los_Angeles},
%  \code{Pacific/Easter}.  Some traditional designations are also allowed
%  such as \code{EST5EDT} or \code{GB}.  (Beware that some of these
%  designations may not be what you expect: in particular \code{EST} is a
%  time zone used in Canada \emph{without} daylight saving time, and not
%  \code{EST5EDT} nor (Australian) Eastern Standard Time.)  The
%  designation can also be an optional colon prepended to the path to a
%  file giving complied zone information (and the examples above are all
%  files in a system-specific location).  See
%  \url{http://www.twinsun.com/tz/tz-link.htm} for more details and
%  references.  By convention, regions with a unique time-zone history
%  since 1970 have specific names in the database, but those with
%  different earlier histories may not.  Each time zone has one or two
%  (the second for DST) \emph{abbreviations} used when formatting times.
%
%  The abbreviations used have changed over the years: for example France
%  used \samp{PMT} (\sQuote{Paris Mean Time}) from 1891 to 1911 then
%  \samp{WET/WEST} up to 1940 and \samp{CET/CEST} from 1946.  (In almost
%  all time zones they have been stable since 1970.)  The POSIX standard
%  allows only one or two abbreviations per time zone, so you may see the
%  current abbreviation(s) used for older times.
%  
%  The function \code{OlsonNames} returns the time-zone names known to
%  the Olson/IANA database on the current system. The system-specific
%  location in the file system varies, e.g.\sspace{}\file{/usr/share/zoneinfo}
%  (Linux, OS X, FreeBSD), \file{/usr/share/lib/zoneinfo} (Solaris, AIX),
%  \ldots.  It is likely that there is a file named something like
%  \file{zone.tab} under that directory listing the locations known as
%  time-zone names (but not for example \code{EST5EDT}): this is read by
%  \code{OlsonNames}.  See also
%  \url{https://en.wikipedia.org/wiki/Zone.tab}.
%
%  Where \R was configured with option \option{--with-internal-tzcode}
%  (the default on OS X and Windows: recommended on Solaris), the database at
%  \code{file.path(R.home("share"), "zoneinfo")} is used by default: file
%  \file{VERSION} in that directory states the version.  Environment
%  variable \env{TZDIR} can be used to point to a different
%  \file{zoneinfo} directory: this is also supported by the native
%  services on some OSes, e.g.\sspace{}Linux).
%#ifdef windows
%
%  An attempt is made (once only per session) to map Windows' idea of the
%  current time zone to a location, following a version of
%  \url{http://unicode.org/repos/cldr/trunk/common/supplemental/windowsZones.xml}
%  with additional values deduced from the Windows Registry and documentation.
%  It can be overridden by setting the \env{TZ} environment variable
%  before any date-times are used in the session.
%#endif
%
%  Most platforms support time zones of the form \samp{GMT+n} and
%  \samp{GMT-n}, which assume at a fixed offset from UTC (hence no DST).
%  Contrary to some expectations (but consistent with names such as
%  \samp{PST8PDT}), negative offsets are times ahead of (east of) UTC,
%  positive offsets are times behind (west of) UTC.
%  
%  Immediately prior to the advent of legislated time zones, most people
%  used time based on their longitude (or that of a nearby town), known
%  as \sQuote{Local Mean Time} and abbreviated as \samp{LMT} in the
%  databases: in many countries that was codified with a specific name
%  before the switch to a standard time.  For example, Paris codified its
%  LMT as \sQuote{Paris Mean Time} in 1891 (to be used throughout
%  mainland France) and switched to \samp{GMT+0} in 1911.
%}
%
%\note{
%  Since 2007 there has been considerable disruption over changes to the
%  timings of the DST transitions, aimed at energy conservation.  These
%  often have short notice and time-zone databases may not be up to date.
%  (Morocco in 2013 announced a change to the end of DST at \emph{a days}
%  notice, and in 2015 North Korea gave imprecise information about a
%  change a week in advance.)
%
%  On platforms with case-insensitive file systems, time zone names will be
%  case-insensitive.  They may or may not be on other platforms and so,
%  for example, \code{"gmt"} is valid on some platforms and not on others.
%
%  Note that except where replaced, the operation of time zones is an OS
%  service, and even where replaced a third-party database is used and
%  can be updated (see the section on \sQuote{Time zone names}).
%  Incorrect results will never be an \R issue, so please ensure that you
%  have the courtesy not to blame \R for them.
%}
%% Unlike Tony Plate and John Pfuntner
%
%\seealso{
%  \code{\link{Sys.time}}, \code{\link{as.POSIXlt}}.
%
%  \url{https://en.wikipedia.org/wiki/Time_zone} and
%  \url{https://www.twinsun.com/tz/tz-link.htm} for extensive sets of links.
%}
%
%\examples{
%Sys.timezone()
%
%str(OlsonNames()) ## a few hundred names
%}
%\keyword{utilities}
%\keyword{chron}
%