% File src/library/base/man/toString.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{toString}
\alias{toString}
\alias{toString.default}

\title{Convert an R Object to a Character String}
\description{
  これは \code{\link{format}} に対するヘルパー関数で，
  \R オブジェクトを記述する一つの文字列を生成する．
}
\usage{
toString(x, \dots)

\method{toString}{default}(x, width = NULL, \dots)
}
\arguments{
  \item{x}{変換されるオブジェクト．}
  \item{width}{最大の欄幅に対する提案．値
    \code{NULL} 又は \code{0} は最大無しを意味する．
    受け入れられる最少値は 6 で，より小さな値は 6 とされる．}
  \item{\dots}{メソッドへ・から渡されるオプション引数．}
}
\details{
  これは総称的関数でそれに対するメソッドを書くことが出来る：
  ここでは既定のメソッドだけを説明する．
  殆どのメソッドは結果の最大表示幅(\code{\link{nchar}(type = "width")} で
  測られた)を指示する \code{width} 引数を尊重すべきである．

  既定メソッドは最初 \code{x} を文字列に変換し，それから
  \code{", "} で分離された要素に連結する．
  もし \code{width} が与えられ \code{NULL} でないと，
  既定のメソッドは，もし結果全体が \code{width} 文字以上を使うと，
  \code{....} を加えた結果の最初の \code{width - 4} 文字を返す．
}
\value{
  長さ1の文字列ベクトルが返される．
}
\author{ Robert Gentleman }

\seealso{ \code{\link{format}} }

\examples{
x <- c("a", "b", "aaaaaaaaaaa")
toString(x)
toString(x, width = 8)
}
\keyword{utilities}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/toString.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{toString}
%\alias{toString}
%\alias{toString.default}
%
%\title{Convert an R Object to a Character String}
%\description{
%  This is a helper function for \code{\link{format}} to produce a single
%  character string describing an \R object.
%}
%\usage{
%toString(x, \dots)
%
%\method{toString}{default}(x, width = NULL, \dots)
%}
%\arguments{
%  \item{x}{The object to be converted.}
%  \item{width}{Suggestion for the maximum field width.  Values of
%    \code{NULL} or \code{0} indicate no maximum.
%    The minimum value accepted is 6 and smaller values are taken as 6.}
%  \item{\dots}{Optional arguments passed to or from methods.}
%}
%\details{
%  This is a generic function for which methods can be written: only the
%  default method is described here.  Most methods should honor the
%  \code{width} argument to specify the maximum display width (as measured
%  by \code{\link{nchar}(type = "width")} of the result.
%
%  The default method first converts \code{x} to character and then
%  concatenates the elements separated by \code{", "}.
%  If \code{width} is supplied and is not \code{NULL}, the default method
%  returns the first \code{width - 4} characters of the result with
%  \code{....} appended, if the full result would use more than
%  \code{width} characters.
%}
%\value{
%  A character vector of length 1 is returned.
%}
%\author{ Robert Gentleman }
%
%\seealso{ \code{\link{format}} }
%
%\examples{
%x <- c("a", "b", "aaaaaaaaaaa")
%toString(x)
%toString(x, width = 8)
%}
%\keyword{utilities}
%