% File src/library/base/man/tracemem.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{tracemem}
\alias{tracemem}
\alias{untracemem}
\alias{retracemem}
\title{Trace Copying of Objects}
\description{
  この関数は内部コードがオブジェクトをコピーする度に
  メッセージがプリントされるようにオブジェクトをマークする．
  これは \R の予測困難なメモリ使用の主因である．
}
\usage{
tracemem(x)
untracemem(x)
retracemem(x, previous = NULL)
}
\arguments{
  \item{x}{R オブジェクトで，関数，環境，\code{NULL} でない．}
  \item{previous}{\code{tracemem} か \code{retracemem} により返される値．}
}
\details{
  オブジェクトを何もトレースしていなくても \R の実行を少し遅くするため，
  この機能はオプションでコンパイル時に決定される．
  \code{tracemem} と \code{untracemem} は \R がメモリプロファイル機能付きで
  コンパイルされていないとエラーを与える；
  \code{retracemem} はエラーを与えない(従って開発中にコードの中に残しておける)．

  これは CRAN の OS X と Windows 用に構築された \R では使用可能とされている．

  オブジェクトがトレースされる時， C 関数 \code{duplicate} による
  オブジェクトのコピーは標準出力にメッセージを生成する．
  引数を \code{.C} 又は \code{.Fortran} に渡すための型変換とコピーの
  際も同様である．

  メッセージは文字列 \code{tracemem}，コピーされるオブジェクトと
  強制変換されるオブジェクトに対する特定のための文字列，
  そしてどこで重複が起きたかを示すスタックのトレースから
  構成される．
  \code{retracemem()} は変数が以前の変数のコピーと考えるべきかどうか
  (例えば，添字操作の後)を指示するために使われる．

  メッセージは \code{\link{tracingState}} で無効に出来る．

  \code{\link{trace}} と衝突するため関数をトレースすることはできない．
  重複しないため \code{NULL}，環境，予約，弱参照，又は外部ポインター
  オブジェクトをトレースすることは役に立たない,

  これらの関数はプリミティブである．
}
\value{
  トレースの出力中のオブジェクトを特定するための文字列
  (角括弧に挟まれた16進数のアドレス)，又は(不可視の) \code{NULL}．
}

\seealso{
  これがこの構築された \R に対して使用可能とされているかどうかを見るには\cr
  \code{\link{capabilities}("profmem")}．

  \code{\link{trace}}, \code{\link{Rprofmem}}

  \url{http://developer.r-project.org/memory-profiling.html}
}
\examples{\dontrun{
a <- 1:10
tracemem(a)
## b と a はメモリを共有する
b <- a
b[1] <- 1
untracemem(a)

## lm 中のコピー：R <= 2.15.0
d <- stats::rnorm(10)
tracemem(d)
lm(d ~ a+log(b))

## f はコピーでなくトレースされない
f <- d[-1]
f+1
## f が d のコピーとしてトレースすべきかどうかを指示する
retracemem(f, retracemem(d))
f+1
}}
\keyword{utilities}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/tracemem.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{tracemem}
%\alias{tracemem}
%\alias{untracemem}
%\alias{retracemem}
%\title{Trace Copying of Objects}
%\description{
%  This function marks an object so that a message is printed whenever the
%  internal code copies the object.  It is a
%  major cause of hard-to-predict memory use in R.
%}
%\usage{
%tracemem(x)
%untracemem(x)
%retracemem(x, previous = NULL)
%}
%\arguments{
%  \item{x}{An R object, not a function or environment or \code{NULL}.}
%  \item{previous}{A value as returned by \code{tracemem} or \code{retracemem}.}
%}
%\details{
%  This functionality is optional, determined at compilation, because it
%  makes R run a little more slowly even when no objects are being
%  traced.  \code{tracemem} and \code{untracemem} give errors when R is not
%  compiled with memory profiling; \code{retracemem} does not (so it can be
%  left in code during development).
%
%  It is enabled in the CRAN OS X and Windows builds of \R.
%
%  When an object is traced any copying of the object by the C function
%  \code{duplicate} produces a message to standard output, as does type
%  coercion and copying when passing arguments to \code{.C} or
%  \code{.Fortran}.
%
%  The message consists of the string \code{tracemem}, the identifying
%  strings for the object being copied and the new object being created,
%  and a stack trace showing where the duplication occurred.
%  \code{retracemem()} is used to indicate that a variable should be
%  considered a copy of a previous variable (e.g., after subscripting).
%
%  The messages can be turned off with \code{\link{tracingState}}.
%
%  It is not possible to trace functions, as this would conflict with
%  \code{\link{trace}} and it is not useful to trace \code{NULL},
%  environments, promises, weak references, or external pointer objects, as
%  these are not duplicated.
%
%  These functions are \link{primitive}.
%}
%\value{
%  A character string for identifying the object in the trace output (an
%  address in hex enclosed in angle brackets), or \code{NULL} (invisibly).
%}
%
%\seealso{
%  \code{\link{capabilities}("profmem")} to see if this was enabled for
%  this build of \R.
%
%  \code{\link{trace}}, \code{\link{Rprofmem}}
%
%  \url{http://developer.r-project.org/memory-profiling.html}
%}
%\examples{\dontrun{
%a <- 1:10
%tracemem(a)
%## b and a share memory
%b <- a
%b[1] <- 1
%untracemem(a)
%
%## copying in lm: less than R <= 2.15.0
%d <- stats::rnorm(10)
%tracemem(d)
%lm(d ~ a+log(b))
%
%## f is not a copy and is not traced
%f <- d[-1]
%f+1
%## indicate that f should be traced as a copy of d
%retracemem(f, retracemem(d))
%f+1
%}}
%\keyword{utilities}
%
%