% File src/library/base/man/weekday.POSIXt.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2009 R Core Team
% Distributed under GPL 2 or later

\name{weekdays}
\alias{weekdays}
\alias{weekdays.POSIXt}
\alias{weekdays.Date}
\alias{months}
\alias{months.POSIXt}
\alias{months.Date}
\alias{quarters}
\alias{quarters.POSIXt}
\alias{quarters.Date}
\alias{julian}
\alias{julian.POSIXt}
\alias{julian.Date}
\title{Extract Parts of a POSIXt or Date Object}
\description{
  曜日，月又は四半期，もしくはジュリアン時間(ある原点からの日数)を
  取り出す．これらは総称的関数である：ここでは内部的な暦日・時刻クラスに対する
  メソッドがドキュメント化されている．
}
\usage{
weekdays(x, abbreviate)
\method{weekdays}{POSIXt}(x, abbreviate = FALSE)
\method{weekdays}{Date}(x, abbreviate = FALSE)

months(x, abbreviate)
\method{months}{POSIXt}(x, abbreviate = FALSE)
\method{months}{Date}(x, abbreviate = FALSE)

quarters(x, abbreviate)
\method{quarters}{POSIXt}(x, \dots)
\method{quarters}{Date}(x, \dots)

julian(x, \dots)
\method{julian}{POSIXt}(x, origin = as.POSIXct("1970-01-01", tz = "GMT"), \dots)
\method{julian}{Date}(x, origin = as.Date("1970-01-01"), \dots)
}
\arguments{
  \item{x}{クラス \code{"POSIXt"} 又は \code{"Date"} を継承するオブジェクト．}
  \item{abbreviate}{論理値．名前を簡略化すべきか?}
  \item{origin}{クラス \code{"POSIXt"} 又は \code{"Date"} を継承する
    長さ 1 のオブジェクト．}
  \item{\dots}{他のメソッドへの引数．}
}
\value{
  \code{weekdays} と \code{months} は使用中のロケールに於ける
  名前の文字列ベクトルを返す．

  \code{quarters} は \code{"Q1"} から \code{"Q4"} までの文字列ベクトルを返す．

  \code{julian} は原点からの日数(小数の可能性)を返す．
  原点は \code{"origin"} 属性で表されている．
  \R に於ける全ての時間計算は閏秒を無視して行われる．
}
\note{
  月や一年の間の日数といった他の成分は非常に簡単に計算できる：
  単に \code{\link{as.POSIXlt}} を使い，そして関連する成分を取り出せば
  良い．別法としては(特に成分を文字列として欲しい時)
  \code{\link{strftime}} を使う．
}

\seealso{
  \code{\link{DateTimeClasses}}, \code{\link{Date}}
}

\examples{\donttest{
weekdays(.leap.seconds)
months(.leap.seconds)
quarters(.leap.seconds)

## ジュリアン日数(JDN, https://en.wikipedia.org/wiki/Julian_day)
## は予測的ユリウス暦による 4317 BC の最初の日の UTC での正午以来の日数である．
## より最近では UTC と数秒異なる '地球時' による，
## https://en.wikipedia.org/wiki/Terrestrial_Time を見よ．
julian(Sys.Date(), -2440588) # 日付から
floor(as.numeric(julian(Sys.time())) + 2440587.5) # 暦日・時刻から
}}
\keyword{chron}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/weekday.POSIXt.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2009 R Core Team
%% Distributed under GPL 2 or later
%
%\name{weekdays}
%\alias{weekdays}
%\alias{weekdays.POSIXt}
%\alias{weekdays.Date}
%\alias{months}
%\alias{months.POSIXt}
%\alias{months.Date}
%\alias{quarters}
%\alias{quarters.POSIXt}
%\alias{quarters.Date}
%\alias{julian}
%\alias{julian.POSIXt}
%\alias{julian.Date}
%\title{Extract Parts of a POSIXt or Date Object}
%\description{
%  Extract the weekday, month or quarter, or the Julian time
%  (days since some origin).  These are generic functions: the methods
%  for the internal date-time classes are documented here.
%}
%\usage{
%weekdays(x, abbreviate)
%\method{weekdays}{POSIXt}(x, abbreviate = FALSE)
%\method{weekdays}{Date}(x, abbreviate = FALSE)
%
%months(x, abbreviate)
%\method{months}{POSIXt}(x, abbreviate = FALSE)
%\method{months}{Date}(x, abbreviate = FALSE)
%
%quarters(x, abbreviate)
%\method{quarters}{POSIXt}(x, \dots)
%\method{quarters}{Date}(x, \dots)
%
%julian(x, \dots)
%\method{julian}{POSIXt}(x, origin = as.POSIXct("1970-01-01", tz = "GMT"), \dots)
%\method{julian}{Date}(x, origin = as.Date("1970-01-01"), \dots)
%}
%\arguments{
%  \item{x}{an object inheriting from class \code{"POSIXt"} or \code{"Date"}.}
%  \item{abbreviate}{logical.  Should the names be abbreviated?}
%  \item{origin}{an length-one object inheriting from class
%    \code{"POSIXt"} or \code{"Date"}.}
%  \item{\dots}{arguments for other methods.}
%}
%\value{
%  \code{weekdays} and \code{months} return a character
%  vector of names in the locale in use.
%
%  \code{quarters} returns a character vector of \code{"Q1"} to
%  \code{"Q4"}.
%
%  \code{julian} returns the number of days (possibly fractional)
%  since the origin, with the origin as a \code{"origin"} attribute.
%  All time calculations in \R are done ignoring leap-seconds.
%}
%\note{
%  Other components such as the day of the month or the year are
%  very easy to compute: just use \code{\link{as.POSIXlt}} and extract
%  the relevant component.  Alternatively (especially if the components
%  are desired as character strings), use \code{\link{strftime}}.
%}
%
%\seealso{
%  \code{\link{DateTimeClasses}}, \code{\link{Date}}
%}
%
%\examples{\donttest{
%weekdays(.leap.seconds)
%months(.leap.seconds)
%quarters(.leap.seconds)
%
%## Julian Day Number (JDN, https://en.wikipedia.org/wiki/Julian_day)
%## is the number of days since noon UTC on the first day of 4317 BC.
%## in the proleptic Julian calendar.  To more recently, in
%## 'Terrestrial Time' which differs from UTC by a few seconds
%## See https://en.wikipedia.org/wiki/Terrestrial_Time
%julian(Sys.Date(), -2440588) # from a day
%floor(as.numeric(julian(Sys.time())) + 2440587.5) # from a date-time
%}}
%\keyword{chron}
%