% File src/library/base/man/xtfrm.Rd
% Part of the R package, https://www.R-project.org
% Copyright 2008-2015 R Core Team
% Distributed under GPL 2 or later

\name{xtfrm}
\alias{xtfrm}
\alias{xtfrm.default}
\alias{xtfrm.factor}
\alias{xtfrm.AsIs}
\alias{xtfrm.Surv}
\alias{xtfrm.Date}
\alias{xtfrm.POSIXct}
\alias{xtfrm.POSIXlt}
\alias{xtfrm.difftime}
\title{Auxiliary Function for Sorting and Ranking}
\description{
  総称的な補助関数で \code{x} と同じ順序でソートする数値ベクトルを
  生成する．
}
\usage{
xtfrm(x)
}
\arguments{
  \item{x}{\R オブジェクト．}
}
\details{
  これはランク付けの特殊なケースであるが，\code{\link{rank}} よりもより一般性が低い
  分総称的とされるのに適している．
  既定のメソッドは \code{rank(x, ties.method = "min", na.last = "keep")} に
  類似しているので，\code{NA} 値はランク \code{NA} を与えられ，
  全てのタイ値は同じ整数値ランクを与えられる．

  因子メソッドはコードを取り出す．
  \code{\link[survival]{Surv}} メソッドは最初時間についてソートし，それから
  状態コードについて，最後にもし存在すれば \code{timme2} についてソートする．
  規約からこれが個別にソートする状態は死亡の前に依然生存している．

  既定メソッドはもし \code{\link{is.numeric}(x)} が真ならば
  オブジェクトのクラスを取り除き，さもなければ \code{x[i]}
  (整数に対しては \code{i}) のクラスに対して
  \code{==} and \code{>} メソッドを使う．そして \code{x} のクラスに対しては
  \code{is.na} メソッドを使うが，そうするとかなり遅い可能性がある，

  これは内部総称的なプリミティブ関数であり，S3 又は S4 メソッドをそれに対して
  書くことが出来る．
}
\value{
  \code{x} と同じ長さの数値(普通整数)ベクトル．
}
\seealso{
  \code{\link{rank}}, \code{\link{sort}}, \code{\link{order}}.
}
\keyword{univar}
\keyword{manip}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/xtfrm.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 2008-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{xtfrm}
%\alias{xtfrm}
%\alias{xtfrm.default}
%\alias{xtfrm.factor}
%\alias{xtfrm.AsIs}
%\alias{xtfrm.Surv}
%\alias{xtfrm.Date}
%\alias{xtfrm.POSIXct}
%\alias{xtfrm.POSIXlt}
%\alias{xtfrm.difftime}
%\title{Auxiliary Function for Sorting and Ranking}
%\description{
%  A generic auxiliary function that produces a numeric vector which
%  will sort in the same order as \code{x}.
%}
%\usage{
%xtfrm(x)
%}
%\arguments{
%  \item{x}{an \R object.}
%}
%\details{
%  This is a special case of ranking, but as a less general function than
%  \code{\link{rank}} is more suitable to be made generic.  The default
%  method is similar to \code{rank(x, ties.method = "min",
%    na.last = "keep")}, so \code{NA} values are given rank \code{NA} and all
%  tied values are given equal integer rank.
%
%  The \code{\link{factor}} method extracts the codes.  The
%  \code{\link[survival]{Surv}} method sorts first on times and then on
%  status code(s), finally on \code{timme2} if present.  Note that with
%  the conventional status codes this sorts individuals still alive before
%  deaths.
%
%  The default method will unclass the object if
%  \code{\link{is.numeric}(x)} is true but otherwise make use of
%  \code{==} and \code{>} methods for the class of \code{x[i]} (for
%  integers \code{i}), and the \code{is.na} method for the class of
%  \code{x}, but might be rather slow when doing so.
%
%  This is an \link{internal generic} \link{primitive}, so S3 or S4
%  methods can be written for it.
%}
%\value{
%  A numeric (usually integer) vector of the same length as \code{x}.
%}
%\seealso{
%  \code{\link{rank}}, \code{\link{sort}}, \code{\link{order}}.
%}
%\keyword{univar}
%\keyword{manip}
%