% File src/library/base/man/zMachine.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{.Machine}
\alias{.Machine}
\concept{long double}
\title{Numerical Characteristics of the Machine}
\usage{
.Machine
}
\description{
  \code{.Machine} は \R が稼働している機械の最大倍精度値や整数そして
  機械精度等の数値的特性に関する情報を保持する変数である．
}
\value{
  以下の成分を持つリスト
  \item{double.eps}{
    \code{1 + x != 1} となる最少の正の浮動小数点数．
    もし \code{double.base} が 2 か \code{double.rounding} が 0 なら
    \code{double.base ^ ulp.digits} に等しい；さもなければそれは
    \code{(double.base ^ double.ulp.digits) / 2}．普通\cr
    \code{2.220446e-16}．}
  \item{double.neg.eps}{
    \code{1 - x != 1} となる小さい正の浮動小数点数．
    もし \code{double.base} が 2 か \code{double.rounding} が 0 なら
    \code{double.base ^ double.neg.ulp.digits} に等しい；さもなければそれは\cr
    \code{(double.base ^ double.neg.ulp.digits) / 2}．普通
    \code{1.110223e-16}．
    \code{double.neg.ulp.digits} は下から \code{-(double.digits + 3)} で
    抑えられるので \code{double.neg.eps} は 1 から引くと 1 では無くなる
    最少の数ではないかもしれない．}
  \item{double.xmin}{最少のゼロでない正規化浮動小数点数，基数の巾乗，つまり\cr
    \code{double.base ^ double.min.exp}．普通 \code{2.225074e-308}．}
  \item{double.xmax}{最大の正規化浮動小数点数．
    典型的には\cr
    \code{(1 - double.neg.eps) * double.base ^ double.max.exp} に等しいが，
    ある種の機械ではそれは二番目か三番目に大きなそうした数で，
    仮数部の最後の桁で 1 または 2 単位だけ小さすぎる．
    普通 \code{1.797693e+308}．より大きな非正規化数が起こり得ることを注意しよう．}
  \item{double.base}{浮動小数点表現の基数：普通 \code{2}．}
  \item{double.digits}{浮動小数点数の仮数の基本数：
    普通 \code{53}．}
  \item{double.rounding}{丸め動作，以下の一つ\cr
    0 浮動小数点加算が切り捨てをする；\cr
    1 浮動小数点加算が丸められ IEEE 式でない；\cr
    2 浮動小数点加算が IEEE 式丸め；\cr
    3 浮動小数点加算が切り捨て，部分的桁落ち；\cr
    4 浮動小数点加算が丸められ IEEE 式でなく，
      部分的な桁落ち；\cr
    5 浮動小数点加算が IEEE 式丸め，部分的桁落ち．\cr
    普通 \code{5}．}
  \item{double.guard}{切り捨て算術を持つ乗算に対するガードビット数．
    これは浮動小数点算術が切り捨てを行えば 1 で，
    基数 \code{double.base} での \code{double digits} 桁数が
    乗算中の浮動小数点仮数の事後正規化シフトに使われる．
    さもなければ 0 である．普通 \code{0}．}
  \item{double.ulp.digits}{
    \code{1 + double.base ^ i != 1} である最大の負の整数 \code{i} であるが
    下から \code{-(double.digits + 3)} で抑えられている．普通 \code{-52}．}
  \item{double.neg.ulp.digits}{
    \code{1 - double.base ^ i != 1} である最大の負の整数 \code{i}
    であるが下から \code{-(double.digits + 3)} で抑えられている．普通 \code{-53}.}
  \item{double.exponent}{
    浮動小数点数の指数の表現(バイアス又は符号を含む)に確保されるビット数
    (\code{double.base} が 10 ならば桁数)．普通 \code{11}．}
  \item{double.min.exp}{
    \code{double.base ^ i} が正で正規化されている絶対値で最大の負の
    整数 \code{i}．普通 \code{-1022}.}
  \item{double.max.exp}{
    桁溢れする最少の \code{double.base} の正の巾乗．普通
    \code{1024}.}
  \item{integer.max}{表現可能な最大整数．
    常に \eqn{2^31 - 1 = 2147483647}．}
  \item{sizeof.long}{C の \code{long} 型のバイト数：
    \code{4} 又は \code{8} (殆どの 64 ビットシステム，しかし Windows は異なる)．}
  \item{sizeof.longlong}{C の \code{long long} 型のバイト数．
    そうした型がなければゼロで，さもなければ普通 \code{8}．}
  \item{sizeof.longdouble}{C の \code{long double} 型中のバイト数．
    そうした型がなければゼロ(もしくは \R の構築時にその
    使用が無効化されている)．さもなければ恐らく
    \code{12} (殆どの 32 ビットビルド)または \code{16} (殆どの 64 ビットビルド)．}
  \item{sizeof.pointer}{C の \code{SEXP} 型のバイト数．
    32 ビットビルドでは \code{4} で 64 ビットビルドでは \code{8}．}
}
\details{
  アルゴリズムは Cody (1988) のサブルーチン MACHAR に基づく．\R の
  現在の実装は全て 32 ビット整数と IEC 60559 浮動小数点(倍精度)算術を
  使うので，最後の四つの値のうちの三つ以外の全てはほとんどすべての \R ビルド
  で同じになる．% sizeof.(long|longdouble|pointer)

  ほとんどのプラットフォームでは
  \code{.Machine$double.xmin} より小さな値が起こり得ることを注意しよう．
  典型的な \R プラットフォームでは最少の正の倍精度値は約
   \code{5e-324} である．
}
\note{
  \code{sizeof.longdouble} は long double に対して確保される記憶メモリ量
  を告げるだけであることを注意しよう(これは普通 \R によって例えば
  \code{\link{sum}} 中の加算器に対して使われ，\code{\link{readBin}} で
  読み取ることができる)．しばしば保管されるのは IEC 60559 の 80 ビット
  拡張倍精度型であり，プラットフォームで使われる倍精度型に揃えるため
  詰め物がされる --- これは ix86 と x86_64 チップを使う普通の \R
  プラットフォームに該当するようである．
}
\source{
  参考文献中の Fortran コードの C への移植を使う．
  最近のコンパイラでの過剰な最適化を抑えるため R Core Team により
  修正されている．
}
\references{
  Cody, W. J. (1988)
  MACHAR: A subroutine to dynamically determine machine parameters.
  \emph{Transactions on Mathematical Software}, \bold{14}, 4, 303--311.
}
\seealso{
  プラットフォームに関する詳細は \code{\link{.Platform}}．
}
\examples{
.Machine
## 綺麗なプリント用には
noquote(unlist(format(.Machine)))
}
\keyword{sysdata}
\keyword{programming}
\keyword{math}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/zMachine.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{.Machine}
%\alias{.Machine}
%\concept{long double}
%\title{Numerical Characteristics of the Machine}
%\usage{
%.Machine
%}
%\description{
%  \code{.Machine} is a variable holding information on the numerical
%  characteristics of the machine \R is running on, such as the largest
%  double or integer and the machine's precision.
%}
%\value{
%  A list with components
%  \item{double.eps}{the smallest positive floating-point number
%    \code{x} such that \code{1 + x != 1}.  It equals
%    \code{double.base ^ ulp.digits} if either \code{double.base} is 2 or
%    \code{double.rounding} is 0;  otherwise, it is
%    \code{(double.base ^ double.ulp.digits) / 2}.  Normally
%    \code{2.220446e-16}.}
%  \item{double.neg.eps}{a small positive floating-point number \code{x}
%    such that \code{1 - x != 1}.  It equals
%    \code{double.base ^ double.neg.ulp.digits} if \code{double.base} is 2
%    or \code{double.rounding} is 0;  otherwise, it is
%    \code{(double.base ^ double.neg.ulp.digits) / 2}.  Normally
%    \code{1.110223e-16}. As \code{double.neg.ulp.digits} is bounded
%    below by \code{-(double.digits + 3)}, \code{double.neg.eps} may not
%    be the smallest number that can alter 1 by subtraction.}
%  \item{double.xmin}{the smallest non-zero normalized
%    floating-point number, a power of the radix, i.e.,
%    \code{double.base ^ double.min.exp}. Normally \code{2.225074e-308}.}
%  \item{double.xmax}{the largest normalized floating-point number.
%    Typically, it is equal to \code{(1 - double.neg.eps) *
%      double.base ^ double.max.exp}, but
%    on some machines it is only the second or third largest such
%    number, being too small by 1 or 2 units in the last digit of the
%    significand.  Normally \code{1.797693e+308}.  Note that larger
%    unnormalized numbers can occur.}
%  \item{double.base}{the radix for the floating-point representation:
%    normally \code{2}.}
%  \item{double.digits}{the number of base digits in the floating-point
%    significand: normally \code{53}.}
%  \item{double.rounding}{the rounding action, one of\cr
%    0 if floating-point addition chops; \cr
%    1 if floating-point addition rounds, but not in the IEEE style; \cr
%    2 if floating-point addition rounds in the IEEE style; \cr
%    3 if floating-point addition chops, and there is partial underflow; \cr
%    4 if floating-point addition rounds, but not in the IEEE style, and
%    there is partial underflow; \cr
%    5 if floating-point addition rounds in the IEEE style, and there is
%    partial underflow.\cr
%    Normally \code{5}.}
%  \item{double.guard}{the number of guard digits for multiplication
%    with truncating arithmetic.  It is 1 if floating-point arithmetic
%    truncates and more than \code{double digits} base-\code{double.base} digits
%    participate in the post-normalization shift of the floating-point
%    significand in multiplication, and 0 otherwise.\cr
%    Normally \code{0}.}
%  \item{double.ulp.digits}{the largest negative integer \code{i} such
%    that \code{1 + double.base ^ i != 1}, except that it is bounded below by
%    \code{-(double.digits + 3)}.  Normally \code{-52}.}
%  \item{double.neg.ulp.digits}{the largest negative integer \code{i}
%    such that \code{1 - double.base ^ i != 1}, except that it is bounded
%    below by \code{-(double.digits + 3)}. Normally \code{-53}.}
%  \item{double.exponent}{
%    the number of bits (decimal places if \code{double.base} is 10) reserved
%    for the representation of the exponent (including the bias or sign)
%    of a floating-point number.  Normally \code{11}.}
%  \item{double.min.exp}{
%    the largest in magnitude negative integer \code{i} such that
%    \code{double.base ^ i} is positive and normalized.  Normally \code{-1022}.}
%  \item{double.max.exp}{
%    the smallest positive power of \code{double.base} that overflows.  Normally
%    \code{1024}.}
%  \item{integer.max}{the largest integer which can be represented.
%    Always \eqn{2^31 - 1 = 2147483647}.}
%  \item{sizeof.long}{the number of bytes in a C \code{long} type:
%    \code{4} or \code{8} (most 64-bit systems, but not Windows).}
%  \item{sizeof.longlong}{the number of bytes in a C \code{long long}
%    type.  Will be zero if there is no such type, otherwise usually
%    \code{8}.}
%  \item{sizeof.longdouble}{the number of bytes in a C \code{long double}
%    type.  Will be zero if there is no such type (or its use was
%    disabled when \R was built), otherwise possibly
%    \code{12} (most 32-bit builds) or \code{16} (most 64-bit builds).}
%  \item{sizeof.pointer}{the number of bytes in a C \code{SEXP}
%    type.  Will be \code{4} on 32-bit builds and \code{8} on 64-bit
%    builds of \R.}
%}
%\details{
%  The algorithm is based on Cody's (1988) subroutine MACHAR.  As all
%  current implementations of \R use 32-bit integers and use IEC 60559
%  floating-point (double precision) arithmetic, all but three of the
%  last four values are the same for almost all \R builds. % sizeof.(long|longdouble|pointer)
%
%  Note that on most platforms smaller positive values than
%  \code{.Machine$double.xmin} can occur.  On a typical \R platform the
%  smallest positive double is about \code{5e-324}.
%}
%\note{
%  \code{sizeof.longdouble} only tells you the amount of storage
%  allocated for a long double (which are normally used internally by \R for
%  accumulators in e.g.\sspace{}\code{\link{sum}}, and can be read by
%  \code{\link{readBin}}).  Often what is stored is the 80-bit extended
%  double type of IEC 60559, padded to the double alignment used on the
%  platform --- this seems to be the case for the common \R platforms
%  using ix86 and x86_64 chips.
%}
%\source{
%  Uses a C translation of Fortran code in the reference, modified by the
%  R Core Team to defeat over-optimization in recent compilers.
%}
%\references{
%  Cody, W. J. (1988)
%  MACHAR: A subroutine to dynamically determine machine parameters.
%  \emph{Transactions on Mathematical Software}, \bold{14}, 4, 303--311.
%}
%\seealso{
%  \code{\link{.Platform}} for details of the platform.
%}
%\examples{
%.Machine
%## or for a neat printout
%noquote(unlist(format(.Machine)))
%}
%\keyword{sysdata}
%\keyword{programming}
%\keyword{math}
%