% File src/library/graphics/man/hist.POSIXt.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{hist.POSIXt}
\alias{hist.POSIXt}
\alias{hist.Date}
\title{Histogram of a Date or Date-Time Object}
\description{
  日付や日付・時刻オブジェクトに適用される \code{\link{hist}} の
  ためのメソッド．
}
\usage{
\method{hist}{POSIXt}(x, breaks, \dots,
     xlab = deparse(substitute(x)),
     plot = TRUE, freq = FALSE,
     start.on.monday = TRUE, format, right = TRUE)

\method{hist}{Date}(x, breaks, \dots,
     xlab = deparse(substitute(x)),
     plot = TRUE, freq = FALSE,
     start.on.monday = TRUE, format, right = TRUE)
}
\arguments{
  \item{x}{クラス \code{"POSIXt"} 又は \code{"Date"} を
    継承するオブジェクト．}
  \item{breaks}{
    切断点\emph{又は} \code{x} が切断される区間の数を与える数
    \emph{又は}区間の指定で \code{"days"}, \code{"weeks"}, 
    \code{"months"}, \code{"quarters"} の一つで，
    日付・時刻オブジェクトに対しては \code{"years"} 
    プラス \code{"secs"}, \code{"mins"}, \code{"hours"}．
 }
  \item{\dots}{グラフィックスパラメータ，又は
    \code{include.lowest}, \code{right} そして \code{labels}
    の様な \code{\link{hist.default}} への引数．}
  \item{xlab}{もしプロットされれば，x 軸に対するラベルを与える文字列．}
  \item{plot}{論理値．もし \code{TRUE} (既定)ならば，ヒストグラムが
    プロットされる，さもなければ分点と計数のリストが返される．}
  \item{freq}{論理値；もし \code{TRUE} ならば，ヒストグラムグラフィックス
    は頻度の表現である，つまり結果の \code{counts} 成分．
    もし \code{FALSE} ならば，\emph{相対}頻度(確率)がプロットされる．}
  \item{start.on.monday}{論理値．もし \code{breaks = "weeks"} ならば，
    週は月曜日に始まるか日曜日に始まるか?}
  \item{format}{x 軸ラベル用．\code{\link{strptime}} を見よ．}
  \item{right}{論理値；もし \code{TRUE} なら，ヒストグラムのセルは
    右に閉じた(左に開いた)区間になる．}
}
\details{
  既定メソッドとは異なり，\code{breaks} は必要な引数であることを
  注意する．

  \code{breaks = "quarters"} の使用は三ヶ月の区間を作り，
  \code{min(x)} に基づき適切さに応じて，区間は1月1日，4月1日，
  7月1日，10月1日に始まる．
  
  既定の \code{right = TRUE} では，
  \code{breaks} が \code{"months"}, \code{"quarters"} 又は
  \code{"years"} の時分点は前の期間の最後の日とされる．
  \code{right = FALSE} の使用はそれらを各バー中に示される
  区間の最初の日に設定する．
}
\value{
  クラス \code{"histogram"} のオブジェクト：\code{\link{hist}} を見よ．
}
\seealso{
  \code{\link{seq.POSIXt}}, \code{\link{axis.POSIXct}}, \code{\link{hist}}
}
\examples{
hist(.leap.seconds, "years", freq = TRUE)
hist(.leap.seconds,
     seq(ISOdate(1970, 1, 1), ISOdate(2020, 1, 1), "5 years"))

## 10週周期の100個のランダム日付
random.dates <- as.Date("2001/1/1") + 70*stats::runif(100)
hist(random.dates, "weeks", format = "\%d \%b")
}
\keyword{chron}
\keyword{dplot}
\keyword{hplot}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/graphics/man/hist.POSIXt.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{hist.POSIXt}
%\alias{hist.POSIXt}
%\alias{hist.Date}
%\title{Histogram of a Date or Date-Time Object}
%\description{
%  Method for \code{\link{hist}} applied to date or date-time objects.
%}
%\usage{
%\method{hist}{POSIXt}(x, breaks, \dots,
%     xlab = deparse(substitute(x)),
%     plot = TRUE, freq = FALSE,
%     start.on.monday = TRUE, format, right = TRUE)
%
%\method{hist}{Date}(x, breaks, \dots,
%     xlab = deparse(substitute(x)),
%     plot = TRUE, freq = FALSE,
%     start.on.monday = TRUE, format, right = TRUE)
%}
%\arguments{
%  \item{x}{an object inheriting from class \code{"POSIXt"} or \code{"Date"}.}
%  \item{breaks}{
%    a vector of cut points \emph{or} number giving the number of
%    intervals which \code{x} is to be cut into \emph{or} an
%    interval specification, one of \code{"days"}, \code{"weeks"},
%    \code{"months"}, \code{"quarters"} or \code{"years"},
%    plus \code{"secs"}, \code{"mins"}, \code{"hours"} for
%    date-time objects.
% }
%  \item{\dots}{\link{graphical parameters}, or arguments to
%    \code{\link{hist.default}} such as \code{include.lowest},
%      \code{right} and \code{labels}.}
%  \item{xlab}{a character string giving the label for the x axis, if plotted.}
%  \item{plot}{logical.  If \code{TRUE} (default), a histogram is
%    plotted, otherwise a list of breaks and counts is returned.}
%  \item{freq}{logical; if \code{TRUE}, the
%    histogram graphic is a representation of frequencies, i.e,
%    the \code{counts} component of the result; if \code{FALSE},
%    \emph{relative} frequencies (probabilities) are plotted.}
%  \item{start.on.monday}{logical. If \code{breaks = "weeks"}, should the
%    week start on Mondays or Sundays?}
%  \item{format}{for the x-axis labels. See \code{\link{strptime}}.}
%  \item{right}{logical; if \code{TRUE}, the histogram cells are
%    right-closed (left open) intervals.}
%}
%\details{
%  Note that unlike the default method, \code{breaks} is a required argument.
%
%  Using \code{breaks = "quarters"} will create intervals of 3 calendar
%  months, with the intervals beginning on January 1, April 1,
%  July 1 or October 1, based upon \code{min(x)} as appropriate.
%  
%  With the default \code{right = TRUE}, breaks will be set
%  on the last day of the previous period when \code{breaks} is
%  \code{"months"}, \code{"quarters"} or \code{"years"}.  Use 
%  \code{right = FALSE} to set them to the first day of the
%  interval shown in each bar.
%}
%\value{
%  An object of class \code{"histogram"}: see \code{\link{hist}}.
%}
%\seealso{
%  \code{\link{seq.POSIXt}}, \code{\link{axis.POSIXct}}, \code{\link{hist}}
%}
%\examples{
%hist(.leap.seconds, "years", freq = TRUE)
%hist(.leap.seconds,
%     seq(ISOdate(1970, 1, 1), ISOdate(2020, 1, 1), "5 years"))
%
%## 100 random dates in a 10-week period
%random.dates <- as.Date("2001/1/1") + 70*stats::runif(100)
%hist(random.dates, "weeks", format = "\%d \%b")
%}
%\keyword{chron}
%\keyword{dplot}
%\keyword{hplot}
%
\encoding{UTF8}
