% File src/library/graphics/man/locator.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2011 R Core Team
% Distributed under GPL 2 or later

\name{locator}
\alias{locator}
\title{Graphical Input}
\description{
  (最初の)マウスボタンが押された時のグラッフィクスカーソルの位置を読み取る．
}
\usage{
locator(n = 512, type = "n", \dots)
}
\arguments{
  \item{n}{位置決めをする点の最大数．適正な値は 1 から始まる．}
  \item{type}{\code{"n"}, \code{"p"}, \code{"l"} または
    \code{"o"} の一つ．もし \code{"p"} か \code{"o"} なら点がプロットされる；
    もし \code{"l"} か \code{"o"} ならばそれらは線で結ばれる．}
  \item{\dots}{\code{type != "n"} の時，位置をプロットするために使われる
    追加のグラフィックスパラメータ．}
}
\value{
  特定された点のユーザ座標システム，つまり \code{\link{par}("usr")} で
  指定されるもの，に於ける座標である \code{x} と \code{y} 成分を持つリスト，
}
\details{
  \code{locator} は \code{X11}, \code{windows} そして \code{quartz}
  のようなスクリーンデバイスの上でだけサポートされる．
  他のデバイス上では呼び出しは何もしない．

  プロセスがユーザにより早まって終了されない限り(下を見よ)
  最大 \code{n} 個の位置が決定される．

#ifdef unix
  通常の \code{\link{X11}} デバイスに対しては，特定プロセスは
  最初以外の任意のマウスボタンを押すことで終了する．
  \code{\link{quartz}} デバイスに対しては，プロセスは
  \code{ESC} キーを押すことで終了する．
#endif
#ifdef windows
  特定プロセスは二番目のマウスボタンをクリックするか
  メニューから\sQuote{Stop}，もしくはグラフィックスウィンド
  上の\sQuote{Stop}メニューを選択することで終了する．
#endif

  現在のグラフィックスパラメータは
  あたかも \code{plot.default} が同じ \code{type} の値を持つ
  \code{plot.default} が呼び出されたかのように適用される．
  点と線のプロットはクリッピングの対象になるが，
  現在のクリッピング矩形の外側の位置は返される．

  \code{locator} をサポートする殆どのデバイスでは，
  \code{\link{options}(locatorBell = FALSE)} が設定されていない限り，
  点の成功裏の選択はベル音で指示される．

  もしウィンドがサイズ変更や隠蔽され，それから入力プロセスが終了する前に
  表示されると，\code{locator} で描かれた線や点は消え去る．
  それらは入力プロセスが終了し，ウィンドがサイズ変更や隠蔽され
  再び表示されるやいなや再び現れる．
  これは \code{locator} で描かれた点と線は，
  入力プロセスが終了するまでデバイスのディスプレイリストに
  記録されないからである．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\seealso{
  \code{\link{identify}}.

  サポートされているかどうかを見るには \code{\link{dev.capabilities}}．
}
\keyword{iplot}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/graphics/man/locator.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2011 R Core Team
%% Distributed under GPL 2 or later
%
%\name{locator}
%\alias{locator}
%\title{Graphical Input}
%\description{
%  Reads the position of the graphics cursor when the (first) mouse
%  button is pressed.
%}
%\usage{
%locator(n = 512, type = "n", \dots)
%}
%\arguments{
%  \item{n}{the maximum number of points to locate.  Valid values start
%    at 1.}
%  \item{type}{One of \code{"n"}, \code{"p"}, \code{"l"} or
%    \code{"o"}. If \code{"p"} or \code{"o"} the points are
%    plotted; if \code{"l"}  or \code{"o"} they are joined by lines.}
%  \item{\dots}{additional graphics parameters used if \code{type != "n"}
%    for plotting the locations.}
%}
%\value{
%  A list containing \code{x} and \code{y} components which are the
%  coordinates of the identified points in the user coordinate system,
%  i.e., the one specified by \code{\link{par}("usr")}.
%}
%\details{
%  \code{locator} is only supported on screen devices such as
%  \code{X11}, \code{windows} and \code{quartz}.  On other devices the
%  call will do nothing.
%
%  Unless the process is terminated prematurely by the user (see below)
%  at most \code{n} positions are determined.
%
%#ifdef unix
%  For the usual \code{\link{X11}} device the identification process is
%  terminated by pressing any mouse button other than the first.
%  For the \code{\link{quartz}} device the process is terminated by
%  pressing the \code{ESC} key.
%#endif
%#ifdef windows
%  The identification process can be terminated by clicking the second
%  button and selecting \sQuote{Stop} from the menu, or from the
%  \sQuote{Stop} menu on the graphics window.
%#endif
%
%  The current graphics parameters apply just as if \code{plot.default}
%  has been called with the same value of \code{type}. The plotting of
%  the points and lines is subject to clipping, but locations outside the
%  current clipping rectangle will be returned.
%
%  On most devices which support \code{locator}, successful selection of
%  a point is indicated by a bell sound unless
%  \code{\link{options}(locatorBell = FALSE)} has been set.
%
%  If the window is resized or hidden and then exposed before the input
%  process has terminated, any lines or points drawn by \code{locator}
%  will disappear.  These will reappear once the input process has
%  terminated and the window is resized or hidden and exposed again.
%  This is because the points and lines drawn by \code{locator} are not
%  recorded in the device's display list until the input process has
%  terminated.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\seealso{
%  \code{\link{identify}}.
%
%  \code{\link{dev.capabilities}} to see if it is supported.
%}
%\keyword{iplot}
%
%\encoding{UTF8}
%