% File src/library/graphics/man/plot.dataframe.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{plot.data.frame}
\alias{plot.data.frame}
\title{Plot Method for Data Frames}
\description{
  \code{plot.data.frame} は総称的関数 \code{\link{plot}} のメソッドである．
  これは数値的データフレームを素早く眺めることを意図している．
}
\usage{
\method{plot}{data.frame}(x, \dots)
}
\arguments{
  \item{x}{クラス \code{data.frame} のオブジェクト．}
  \item{\dots}{code{\link{stripchart}},
    \code{\link{plot.default}} 又は \code{\link{pairs}} への追加引数．}
}
\details{
  これは\emph{数値}列を持つデータフレームを念頭に置いている．
  二つ以上の列に対しては，先ずデータフレームを数値行列に変換するために
  \code{\link{data.matrix}} を呼び出し，
  それから散布図行列を作るために \code{\link{pairs}} を呼び出す．
  これは失敗するかもしれず不適切かもしれない：
  例えば日付の数値変換はそれらの特殊な意味を失い警告が出る．

  2列のデータフレームに対しては，これは2番目の列を最初の列に対して
  最初の列に最も相応しいメソッドを使ってプロットする．

  数値列が一つならこれは \code{\link{stripchart}} を使い，他の
  一行のデータフレームに対してはその列に対するプロットメソッドを
  探す．
}
\seealso{
  \code{\link{data.frame}}
}
\examples{
plot(OrchardSprays[1], method = "jitter")
plot(OrchardSprays[c(4,1)])
plot(OrchardSprays)

plot(iris)
plot(iris[5:4])
plot(women)
}
\keyword{hplot}
\keyword{methods}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/graphics/man/plot.dataframe.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{plot.data.frame}
%\alias{plot.data.frame}
%\title{Plot Method for Data Frames}
%\description{
%  \code{plot.data.frame}, a method for the \code{\link{plot}} generic.
%  It is designed for a quick look at numeric data frames.
%}
%\usage{
%\method{plot}{data.frame}(x, \dots)
%}
%\arguments{
%  \item{x}{object of class \code{data.frame}.}
%  \item{\dots}{further arguments to \code{\link{stripchart}},
%    \code{\link{plot.default}} or \code{\link{pairs}}.}
%}
%\details{
%  This is intended for data frames with \emph{numeric} columns. For more
%  than two columns it first calls \code{\link{data.matrix}} to convert
%  the data frame to a numeric matrix and then calls \code{\link{pairs}}
%  to produce a scatterplot matrix).  This can fail and may well be
%  inappropriate: for example numerical conversion of dates will lose
%  their special meaning and a warning will be given.
%
%  For a two-column data frame it plots the second column against the
%  first by the most appropriate method for the first column.
%
%  For a single numeric column it uses \code{\link{stripchart}}, and for
%  other single-column data frames tries to find a plot method for the
%  single column.
%}
%\seealso{
%  \code{\link{data.frame}}
%}
%\examples{
%plot(OrchardSprays[1], method = "jitter")
%plot(OrchardSprays[c(4,1)])
%plot(OrchardSprays)
%
%plot(iris)
%plot(iris[5:4])
%plot(women)
%}
%\keyword{hplot}
%\keyword{methods}
%
%\encoding{UTF8}
%