% File src/library/graphics/man/smoothscatter.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{smoothScatter}
\alias{smoothScatter}
\title{Scatterplots with Smoothed Densities Color Representation}

\description{\code{smoothScatter} は(2次元)カーネル密度推定で得られた
  散布図の平滑化色付き密度推定表現を作る．
}
\usage{
smoothScatter(x, y = NULL, nbin = 128, bandwidth,
              colramp = colorRampPalette(c("white", blues9)),
              nrpoints = 100, ret.selection = FALSE,
              pch = ".", cex = 1, col = "black",
              transformation = function(x) x^.25,
              postPlotHook = box,
              xlab = NULL, ylab = NULL, xlim, ylim,
              xaxs = par("xaxs"), yaxs = par("yaxs"), ...)
}
\arguments{
  \item{x, y}{\code{x} と \code{y} 引数はプロットに対する x と y
    座標を提供する．任意の合理的な座標定義が受け入れられる．
    詳細は関数 \code{\link{xy.coords}} を見よ．
    もし個別に与えられると，それらは同じ長さでなければならない．}
  \item{nbin}{
    密度推定のための等間隔のグリッド点の数を指定する
    長さ 1 (両方向用)か 2 (x と y 方向に個別)の数値ベクトル；
    \code{\link[KernSmooth]{bkde2D}()} 中の
    \code{gridsize} として直接使われる．}
  \item{bandwidth}{平滑化バンド幅(長さ 1 か 2)の数値ベクトル．
    もし欠損すれば多かれ少なかれ有用な既定値が使われる．
    \code{bandwidth} はその後関数
    \code{\link[KernSmooth]{bkde2D}} に渡される．}
  \item{colramp}{
    引数として整数 \code{n} を受け入れ
    \code{n} 個の色を返す．}
  \item{nrpoints}{密度イメージの上に重ね描きされる点の数．
    低い密度領域からの最初の \code{nrpoints} 個の点がプロットされる．
    プロットへの点の追加は外れ値の特定を許す．
    もし全ての点をプロットしたければ \code{nrpoints = Inf} とする．}
  \item{ret.selection}{
    もし \code{nrpoints > 0} ならば\dQuote{低密度}の点を
    大小順に並べ替えて返すべきかどうかを指定する論理値．}
  \item{pch, cex, col}{
    \code{nrpoints > 0} の時 \code{\link{points}} へ
    渡される引数：点シンボル，文字拡大率そして色，
    \code{\link{par}} を見よ．}
  \item{transformation}{密度スケールを色スケールにマップする関数．}
  \item{postPlotHook}{
    \code{NULL} か
    \code{\link{image}} の後に(引数無しで)呼び出される関数．}
  \item{xlab, ylab}{軸ラベルとして使われる文字列で，
    \code{\link{image}} に渡される．}
  \item{xlim, ylim}{軸限界を指定する長さが 2 の数値ベクトル．}
  \item{xaxs, yaxs, \dots}{
    \code{\link{image}} に渡される追加引数，例えば
    \code{add=TRUE} や \code{useRaster=TRUE}．}
}
\value{
  もし \code{ret.selection} が真なら，
  長さ \code{nrpoints} 
  (又は，もし \code{xlim} と \code{ylim} の間に有限値が少なければ 
  それ以下)の整数ベクトルで，描かれる低密度点の添字を含み，
  最低の密度が最初に来るように並べ替えられている．
}
\details{
  \code{smoothScatter} は散布図の平滑化バージョンを作る．
  2次元(カーネル密度)平滑化はパッケージ \CRANpkg{KernSmooth} からの
  \code{\link[KernSmooth]{bkde2D}} を使う．
  この関数を \code{\link{pairs}} と一緒に使う方法は例を見よ．
}
\seealso{
  パッケージ \CRANpkg{KernSmooth} からの \code{\link[KernSmooth]{bkde2D}}；
  同じ平滑化計算とパッケージ \pkg{grDevices} 中の \code{\link{blues9}} を
  使う \code{\link{densCols}}．

  \code{\link{scatter.smooth}} は \code{\link{loess}}
  回帰平滑化を散布図に加える．
}
\author{オリジナルは Florian Hahne at FHCRC}
\examples{\donttest{
## やや大きいデータセット
n <- 10000
x1  <- matrix(rnorm(n), ncol = 2)
x2  <- matrix(rnorm(n, mean = 3, sd = 1.5), ncol = 2)
x   <- rbind(x1, x2)

oldpar <- par(mfrow = c(2, 2), mar=.1+c(3,3,1,1), mgp = c(1.5, 0.5, 0))
smoothScatter(x, nrpoints = 0)
smoothScatter(x)

## 異なった色スキーム：
Lab.palette <- colorRampPalette(c("blue", "orange", "red"), space = "Lab")
i.s <- smoothScatter(x, colramp = Lab.palette,
                     ## pch=NA: それらを描かない
                     nrpoints = 250, ret.selection=TRUE)
## 20個の非常に密度が低い点をラベル，"外れ値" (観測値付き)：
i.20 <- i.s[1:20]
text(x[i.20,], labels = i.20, cex= 0.75)

## 同じ平滑化計算を用いた，少し似た例，
## しかし本当に大きなデータに対しては相当効率が悪い：
plot(x, col = densCols(x), pch = 20)

## pairs と一緒に使う：
par(mfrow = c(1, 1))
y <- matrix(rnorm(40000), ncol = 4) + 3*rnorm(10000)
y[, c(2,4)] <-  -y[, c(2,4)]
pairs(y, panel = function(...) smoothScatter(..., nrpoints = 0, add = TRUE),
      gap = 0.2)

par(oldpar)
}}
\keyword{hplot}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/graphics/man/smoothscatter.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{smoothScatter}
%\alias{smoothScatter}
%\title{Scatterplots with Smoothed Densities Color Representation}
%
%\description{\code{smoothScatter} produces a smoothed color density
%  representation of a scatterplot, obtained through a (2D) kernel
%  density estimate.
%}
%\usage{
%smoothScatter(x, y = NULL, nbin = 128, bandwidth,
%              colramp = colorRampPalette(c("white", blues9)),
%              nrpoints = 100, ret.selection = FALSE,
%              pch = ".", cex = 1, col = "black",
%              transformation = function(x) x^.25,
%              postPlotHook = box,
%              xlab = NULL, ylab = NULL, xlim, ylim,
%              xaxs = par("xaxs"), yaxs = par("yaxs"), ...)
%}
%\arguments{
%  \item{x, y}{the \code{x} and \code{y} arguments provide the x and y
%    coordinates for the plot.  Any reasonable way of defining the
%    coordinates is acceptable.  See the function \code{\link{xy.coords}}
%    for details.  If supplied separately, they must be of the same length.}
%  \item{nbin}{numeric vector of length one (for both directions) or two
%    (for x and y separately) specifying the number of equally spaced
%    grid points for the density estimation; directly used as
%    \code{gridsize} in \code{\link[KernSmooth]{bkde2D}()}.}
%  \item{bandwidth}{numeric vector (length 1 or 2) of smoothing bandwidth(s).
%    If missing, a more or less useful default is used. \code{bandwidth}
%    is subsequently passed to function
%    \code{\link[KernSmooth]{bkde2D}}.}
%  \item{colramp}{function accepting an integer \code{n} as an argument and
%    returning \code{n} colors.}
%  \item{nrpoints}{number of points to be superimposed on the density
%    image.  The first \code{nrpoints} points from those areas of lowest
%    regional densities will be plotted.  Adding points to the plot
%    allows for the identification of outliers.  If all points are to be
%    plotted, choose \code{nrpoints = Inf}.}
%  \item{ret.selection}{\code{\link{logical}} indicating to return the
%    ordered indices of \dQuote{low density} points if \code{nrpoints > 0}.}
%  \item{pch, cex, col}{arguments passed to \code{\link{points}},
%    when \code{nrpoints > 0}: point symbol, character expansion factor
%    and color, see also \code{\link{par}}.}
%  \item{transformation}{function mapping the density scale to the color scale.}
%  \item{postPlotHook}{either \code{NULL} or a function which will be
%    called (with no arguments) after \code{\link{image}}.}
%  \item{xlab, ylab}{character strings to be used as axis labels, passed
%    to \code{\link{image}}.}
%  \item{xlim, ylim}{numeric vectors of length 2 specifying axis limits.}
%  \item{xaxs, yaxs, \dots}{further arguments passed to \code{\link{image}},
%    e.g., \code{add=TRUE} or \code{useRaster=TRUE}.}
%}
%\value{
%  If \code{ret.selection} is true, a vector of integers of length
%  \code{nrpoints} (or smaller, if there are less finite points inside
%  \code{xlim} and \code{ylim}) with the indices of the low-density
%  points drawn, ordered with lowest density first.
%}
%\details{
%  \code{smoothScatter} produces a smoothed version of a scatter plot.
%  Two dimensional (kernel density) smoothing is performed by
%  \code{\link[KernSmooth]{bkde2D}} from package \CRANpkg{KernSmooth}.
%  See the examples for how to use this function together with
%  \code{\link{pairs}}.
%}
%\seealso{
%  \code{\link[KernSmooth]{bkde2D}} from package \CRANpkg{KernSmooth};
%  \code{\link{densCols}} which uses the same smoothing computations and
%  \code{\link{blues9}} in package \pkg{grDevices}.
%
%  \code{\link{scatter.smooth}} adds a \code{\link{loess}}
%  regression smoother to a scatter plot.
%}
%\author{Florian Hahne at FHCRC, originally}
%\examples{\donttest{
%## A largish data set
%n <- 10000
%x1  <- matrix(rnorm(n), ncol = 2)
%x2  <- matrix(rnorm(n, mean = 3, sd = 1.5), ncol = 2)
%x   <- rbind(x1, x2)
%
%oldpar <- par(mfrow = c(2, 2), mar=.1+c(3,3,1,1), mgp = c(1.5, 0.5, 0))
%smoothScatter(x, nrpoints = 0)
%smoothScatter(x)
%
%## a different color scheme:
%Lab.palette <- colorRampPalette(c("blue", "orange", "red"), space = "Lab")
%i.s <- smoothScatter(x, colramp = Lab.palette,
%                     ## pch=NA: do not draw them
%                     nrpoints = 250, ret.selection=TRUE)
%## label the 20 very lowest-density points,the "outliers" (with obs.number):
%i.20 <- i.s[1:20]
%text(x[i.20,], labels = i.20, cex= 0.75)
%
%## somewhat similar, using identical smoothing computations,
%## but considerably *less* efficient for really large data:
%plot(x, col = densCols(x), pch = 20)
%
%## use with pairs:
%par(mfrow = c(1, 1))
%y <- matrix(rnorm(40000), ncol = 4) + 3*rnorm(10000)
%y[, c(2,4)] <-  -y[, c(2,4)]
%pairs(y, panel = function(...) smoothScatter(..., nrpoints = 0, add = TRUE),
%      gap = 0.2)
%
%par(oldpar)
%}}
%\keyword{hplot}
%
%\encoding{UTF8}
%